@@ -28,9 +28,9 @@
 
 StatsDXCCOnSatsWidget::StatsDXCCOnSatsWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-
+    Q_UNUSED(parent);
 #ifdef QT_DEBUG
-    //qDebug() << "StatsDxccOnSatsWidget::StatsDxccOnSatsWidget" << QT_ENDL;
+    //qDebug() << "StatsDxccOnSatsWidget::StatsDxccOnSatsWidget";
 #else
 #endif
 
@@ -102,7 +102,7 @@ StatsDXCCOnSatsWidget::~StatsDXCCOnSatsWidget()
 
 void StatsDXCCOnSatsWidget::prepareChart(const int _log)
 {
-    //qDebug() << Q_FUNC_INFO << "Log = " << QString::number(_log) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << "Log = " << QString::number(_log);
 
      while(tableWidget->rowCount()>0)
      {
@@ -121,7 +121,7 @@ void StatsDXCCOnSatsWidget::prepareChart(const int _log)
      tableWidget->setHorizontalHeaderItem(5, new QTableWidgetItem(tr("Satellite")));
      tableWidget->setHorizontalHeaderItem(6, new QTableWidgetItem(tr("Confirmed")));
      tableWidget->setStyleSheet("QHeaderView::section { background-color:cornflowerblue }");
-     //qDebug() << "StatsDxccOnSatsWidget::prepareChart: QSOs: " << QString::number(_qsos.length()) << QT_ENDL;
+     //qDebug() << "StatsDxccOnSatsWidget::prepareChart: QSOs: " << QString::number(_qsos.length());
 
      int number = 0;
      QList<int> entities;
@@ -167,7 +167,7 @@ void StatsDXCCOnSatsWidget::prepareChart(const int _log)
 
              if (printThisOne)
              {
-                 //qDebug() << "StatsDxccOnSatsWidget::prepareChart: QSOs: printThisOne: " << (_qsos.at(i)->getCall())  << QT_ENDL;
+                 //qDebug() << "StatsDxccOnSatsWidget::prepareChart: QSOs: printThisOne: " << (_qsos.at(i)->getCall()) ;
                  entities.append(_qsos.at(i)->getDXCC());
                  number++;
                  tableWidget->insertRow(tableWidget->rowCount());
