@@ -26,23 +26,16 @@
 
 #include "statsworkedconfirmedpiechartwidget.h"
 
-StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget()
-{
-    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
-    chart = new QChart();
-    chartView = new QChartView(chart);
-}
-
 StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-
+    Q_UNUSED(parent);
 #ifdef QT_DEBUG
-      //qDebug() << "StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget" << QT_ENDL;
+      //qDebug() << "StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget";
 #else
 #endif
     dataProxy = dp;
-    chart = new QChart();
-    chartView = new QChartView(chart);
+    //chart = new QChart();
+    chartView = new QChartView();
 
     createUI();
     //prepareChart();
@@ -55,9 +48,7 @@ StatsWorkedConfirmedPieChartWidget::~StatsWorkedConfirmedPieChartWidget()
 
 void StatsWorkedConfirmedPieChartWidget::createUI()
 {
-    chart->setAnimationOptions(QChart::SeriesAnimations);
-    chart->legend()->setVisible(true);
-    chart->legend()->setAlignment(Qt::AlignBottom);
+
     chartView->setRenderHint(QPainter::Antialiasing);
 
     QVBoxLayout *graphLayout = new QVBoxLayout;
@@ -67,13 +58,18 @@ void StatsWorkedConfirmedPieChartWidget::createUI()
 
 void StatsWorkedConfirmedPieChartWidget::prepareChart(const int _log)
 {
+    QChart *chart = new QChart();
+    chart->setAnimationOptions(QChart::SeriesAnimations);
+    chart->legend()->setVisible(true);
+    chart->legend()->setAlignment(Qt::AlignBottom);
+
     QPieSeries *series = new QPieSeries();
     //PieSlice append(string label, real value)
     int qsos = dataProxy->getHowManyQSOInLog(_log);
     int confirmed = dataProxy->getHowManyConfirmedQSLInLog(_log);
-       //qDebug() << "QSOs: " << QString::number(qsos) << QT_ENDL;
-       //qDebug() << "Confirmed: " << QString::number(confirmed) << QT_ENDL;
-       //qDebug() << "Worked: " << QString::number(qsos - confirmed) << QT_ENDL;
+       //qDebug() << "QSOs: " << QString::number(qsos);
+       //qDebug() << "Confirmed: " << QString::number(confirmed);
+       //qDebug() << "Worked: " << QString::number(qsos - confirmed);
 
     series->append(tr("Worked, not confirmed - %1").arg(qsos-confirmed), qsos - confirmed);
     series->append(tr("Confirmed - %2").arg(confirmed), confirmed);
@@ -95,6 +91,6 @@ void StatsWorkedConfirmedPieChartWidget::prepareChart(const int _log)
     chart->legend()->hide();
 
     chartView->setRenderHint(QPainter::Antialiasing);
-
+    chartView->setChart (chart);
 
 }
