@@ -36,9 +36,9 @@ TODO: Call the creation of this depending on the bands that the user is using
 
 DXCCStatusWidget::DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent) : QWidget(parent)
 {
-
+    Q_UNUSED(_parentFunction);
 #ifdef QT_DEBUG
-  //qDebug() << "DXCCStatusWidget::DXCCStatusWidget from: " << _parentFunction << QT_ENDL;
+  //qDebug() << "DXCCStatusWidget::DXCCStatusWidget from: " << _parentFunction;
 #else
 #endif
 
@@ -46,12 +46,12 @@ DXCCStatusWidget::DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentF
     dataProxy = dp;
     locator = new Locator();
     awards = new Awards(dataProxy, Q_FUNC_INFO);
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-1" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-1";
     world = new World(dataProxy,Q_FUNC_INFO);
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-2" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-2";
 
     dxccView = new QTableWidget;
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-3" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-3";
     dxccView->setMouseTracking(true);
     dxccView->setSortingEnabled(true);
     numberOfColumns = 0;
@@ -62,11 +62,11 @@ DXCCStatusWidget::DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentF
 
     bandNames.clear();
     validBands.clear();
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-4" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-4";
     //setDefaultBands();
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-5" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget-5";
     createUI();
-      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget - END" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::DXCCStatusWidget - END";
 }
 
 DXCCStatusWidget::~DXCCStatusWidget()
@@ -79,26 +79,26 @@ DXCCStatusWidget::~DXCCStatusWidget()
 void DXCCStatusWidget::createUI()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-      //qDebug() << "DXCCStatusWidget::createUI " << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI ";
 
     // We remove the vertical header
     hv = dxccView->verticalHeader();
     hv->hide();
     hv->setStretchLastSection(true);
     hh = dxccView->horizontalHeader();
-      //qDebug() << "DXCCStatusWidget::createUI-10" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-10";
     refreshButton->setText(tr("Update"));
 
-    //qDebug() << "DXCCStatusWidget::createUI-11" << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::createUI-11";
 
     dxccView->setContextMenuPolicy(Qt::CustomContextMenu);
-    //qDebug << "DXCCStatusWidget::createUI-12 - setting column count: " << QString::number(numberOfColumns) << QT_ENDL;
+    //qDebug << "DXCCStatusWidget::createUI-12 - setting column count: " << QString::number(numberOfColumns);
     dxccView->setColumnCount(numberOfColumns);
-    //qDebug() << "DXCCStatusWidget::createUI-13" << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::createUI-13";
     dxccView->horizontalHeader()->setStretchLastSection(true);
-    //qDebug() << "DXCCStatusWidget::createUI-14" << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::createUI-14";
     dxccView->setRowCount(0);
-      //qDebug() << "DXCCStatusWidget::createUI-20" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-20";
     QHBoxLayout *bottonLineLayout = new QHBoxLayout;
     bottonLineLayout->addSpacerItem(new QSpacerItem(10,0,QSizePolicy::Expanding,QSizePolicy::Maximum));
     bottonLineLayout->addWidget(refreshButton);
@@ -107,26 +107,26 @@ void DXCCStatusWidget::createUI()
     tabLayout->addWidget(dxccView);
     tabLayout->addLayout(bottonLineLayout);
     setLayout(tabLayout);
-      //qDebug() << "DXCCStatusWidget::createUI-30" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-30";
     dxccView->resizeColumnsToContents();
     dxccView->resizeRowsToContents();
-      //qDebug() << "DXCCStatusWidget::createUI-90" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-90";
     connect(refreshButton, SIGNAL(clicked()), this, SLOT(slotRefreshButtonClicked() ) );
-      //qDebug() << "DXCCStatusWidget::createUI-91" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-91";
     connect(dxccView, SIGNAL(itemDoubleClicked(QTableWidgetItem *)), this, SLOT(slotItemDoubleClicked(QTableWidgetItem *) ) );
-      //qDebug() << "DXCCStatusWidget::createUI-92" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-92";
     connect(dxccView, SIGNAL(itemEntered(QTableWidgetItem *)), this, SLOT(slotItemEntered(QTableWidgetItem *) ) );
     //connect(dxccView, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRightButton( const QPoint& ) ) );
-      //qDebug() << "DXCCStatusWidget::createUI-93" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-93";
     //dxccView->setSortingEnabled(false);
-      //qDebug() << "DXCCStatusWidget::createUI-END" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::createUI-END";
     emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void DXCCStatusWidget::update()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-    //qDebug()  << Q_FUNC_INFO << ": " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug()  << Q_FUNC_INFO << ": " << QTime::currentTime().toString("HH:mm:ss");
     //int entities = world->getHowManyEntities();
     int entities = dataProxy->getMaxEntityID(false);
     if (!awards->updateDXCCBandsStatus (-1)) // We update all
@@ -172,21 +172,21 @@ void DXCCStatusWidget::update()
         bandIds.append (dataProxy->getIdFromBandName (aux));
     }
 
-    //qDebug() << "DXCCStatusWidget::update: " << QString::number(entities) << " entities to update" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::update: " << QString::number(entities) << " entities to update" << QTime::currentTime().toString("HH:mm:ss");
     QList<int> list;
-    //qDebug() << "DXCCStatusWidget::update: -1"  << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::update: -1"  << QTime::currentTime().toString("HH:mm:ss");
     list.clear();
-    //qDebug() << "DXCCStatusWidget::update: -2"  << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::update: -2"  << QTime::currentTime().toString("HH:mm:ss");
     //QString prefix;
-    //qDebug() << "DXCCStatusWidget::update: -3"  << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::update: -3"  << QTime::currentTime().toString("HH:mm:ss");
     if (dxccView->columnCount()>0)
     {
         dxccView->clearContents();
 
-        //qDebug() << "DXCCStatusWidget::update pre FOR" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::update pre FOR" << QTime::currentTime().toString("HH:mm:ss");
         for (int i=1; i<=entities; i++)
         {
-            //qDebug() << "DXCCStatusWidget::update in FOR " << QString::number(i) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::update in FOR " << QString::number(i) << QTime::currentTime().toString("HH:mm:ss");
             list.clear();
             //if (aux.length()>2)  // Not all integers refers to an entity.
             //{
@@ -197,7 +197,7 @@ void DXCCStatusWidget::update()
         }
     }
     emit debugLog (Q_FUNC_INFO, "END", Debug);
-    //qDebug() << "DXCCStatusWidget::update END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::update END" << QTime::currentTime().toString("HH:mm:ss");
 }
 
 void DXCCStatusWidget::addEntity(const QList<int> &_ent)
@@ -206,18 +206,18 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
     // _ent.at(0) = dxcc column of Entity Table (considering big numbers, like 2248 for IT9!)
     // _ent.at(1) until number of Columns are just the bandnames
 
-    //qDebug() << "DXCCStatusWidget::addEntity: " << QString::number(_ent.at(0)) << "/" <<QString::number(_ent.at(1)) << " / " << QString::number(_ent.length()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: " << QString::number(_ent.at(0)) << "/" <<QString::number(_ent.at(1)) << " / " << QString::number(_ent.length()) << QTime::currentTime().toString("HH:mm:ss");
     // DXCC id, Entity Name, bandName1, bandName2, ...
 
     if (_ent.length() != numberOfColumns-1)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
     int status = -1;
 
-    //qDebug() << "DXCCStatusWidget::addEntity: ent = " << _ent << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: ent = " << _ent << QTime::currentTime().toString("HH:mm:ss");
     int _dxcc = _ent.at(0);
     QStringList data;
     data.clear();
@@ -225,7 +225,7 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
 
     if (data.length ()!=3)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: Wrong Entity Name and Prefix - END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: Wrong Entity Name and Prefix - END" << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
@@ -235,7 +235,7 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
 
     if ((entName.length()<2) || (prefix.length ()<1) || (isoName.length ()<2))
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
@@ -255,12 +255,12 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
     //flagSt = ":/flags/" + isoName + ".png";
     QIcon flagIcon(flagSt);
 
-    //qDebug() << "DXCCStatusWidget::addEntity: Name: " << entName << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::addEntity: Prefix: " << prefix << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: Name: " << entName << QTime::currentTime().toString("HH:mm:ss");
+    //qDebug() << "DXCCStatusWidget::addEntity: Prefix: " << prefix << QTime::currentTime().toString("HH:mm:ss");
+    //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << QTime::currentTime().toString("HH:mm:ss");
 
     dxccView->insertRow(dxccView->rowCount());
-    //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << QTime::currentTime().toString("HH:mm:ss");
 
     QTableWidgetItem *newItemID = new QTableWidgetItem(prefix);
     newItemID->setTextAlignment(Qt::AlignCenter);
@@ -294,7 +294,7 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
         }
 
         dxccView->setItem(dxccView->rowCount()-1, i+1, newItem);
-        //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << QTime::currentTime().toString("HH:mm:ss");
     }
 
     QTableWidgetItem *newItemPref = new QTableWidgetItem(prefix);
@@ -324,7 +324,7 @@ void DXCCStatusWidget::addEntity(const QList<int> &_ent)
     }
     dxccView->setItem(dxccView->rowCount()-1, 0, newItemPref);
     dxccView->setItem(dxccView->rowCount()-1, 1, newItemName);
-    //qDebug() << "DXCCStatusWidget::addEntity: END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: END" << QTime::currentTime().toString("HH:mm:ss");
     emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
@@ -342,17 +342,17 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
     //{
     //   au = au + " - " + a;
     //}
-    //qDebug() << Q_FUNC_INFO << ": " << au << " - " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;;
+    //qDebug() << Q_FUNC_INFO << ": " << au << " - " << QTime::currentTime().toString("HH:mm:ss");;
 
     if (_ent.length() != numberOfColumns-1)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
     int status = -1;
 
-    //qDebug() << "DXCCStatusWidget::addEntity: ent = " << _ent << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: ent = " << _ent << QTime::currentTime().toString("HH:mm:ss");
     int _dxcc = _ent.at(0).toInt();
     QStringList data;
     data.clear();
@@ -360,7 +360,7 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
 
     if (data.length ()!=3)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: Wrong Entity Name and Prefix - END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: Wrong Entity Name and Prefix - END" << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
     //au = "data: ";
@@ -375,7 +375,7 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
 
     if ((entName.length()<2) || (prefix.length ()<1) || (isoName.length ()<2))
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
@@ -394,12 +394,12 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
     flagSt = ":/flags/" + isoName + ".png";
     QIcon flagIcon(flagSt);
 
-    //qDebug() << "DXCCStatusWidget::addEntity: Name: " << entName << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::addEntity: Prefix: " << prefix << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: Name: " << entName << QTime::currentTime().toString("HH:mm:ss");
+    //qDebug() << "DXCCStatusWidget::addEntity: Prefix: " << prefix << QTime::currentTime().toString("HH:mm:ss");
+    //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << QTime::currentTime().toString("HH:mm:ss");
 
     dxccView->insertRow(dxccView->rowCount());
-    //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << QTime::currentTime().toString("HH:mm:ss");
 
     QTableWidgetItem *newItemID = new QTableWidgetItem(prefix);
     newItemID->setTextAlignment(Qt::AlignCenter);
@@ -434,7 +434,7 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
         }
 
         dxccView->setItem(dxccView->rowCount()-1, i+1, newItem);
-        //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << QTime::currentTime().toString("HH:mm:ss");
     }
 
     QTableWidgetItem *newItemPref = new QTableWidgetItem(prefix);
@@ -464,14 +464,14 @@ void DXCCStatusWidget::addEntity2(const QStringList &_ent)
     }
     dxccView->setItem(dxccView->rowCount()-1, 0, newItemPref);
     dxccView->setItem(dxccView->rowCount()-1, 1, newItemName);
-    //qDebug() << "DXCCStatusWidget::addEntity: END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::addEntity: END" << QTime::currentTime().toString("HH:mm:ss");
     emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void DXCCStatusWidget::setBands(const QString &_callingFunc, QStringList const &_ent, const bool _creating)
 {// Receives the list of band names and defines the columns
-    //qDebug() << Q_FUNC_INFO << "(" << _callingFunc << ")" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-
+    //qDebug() << Q_FUNC_INFO << "(" << _callingFunc << ")" << QTime::currentTime().toString("HH:mm:ss");
+    Q_UNUSED(_callingFunc);
     //foreach(QString aux, _ent)
     //{
     //    //qDebug << Q_FUNC_INFO << ": " << aux;
@@ -479,12 +479,12 @@ void DXCCStatusWidget::setBands(const QString &_callingFunc, QStringList const &
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
     QStringList qs;
     qs.clear();
-    //qDebug() << "DXCCStatusWidget::setBands - 01" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 01" << QTime::currentTime().toString("HH:mm:ss");
     qs << dataProxy->sortBandNamesBottonUp(_ent);
-    //qDebug() << "DXCCStatusWidget::setBands - 02: Lenght qs: " << QString::number(qs.size()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 02: Lenght qs: " << QString::number(qs.size()) << QTime::currentTime().toString("HH:mm:ss");
     if (qs.length()<0)
     {
-        //qDebug() << "DXCCStatusWidget::setBands no bands received here " << QTime::currentTime().toString("HH:mm:ss") << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::setBands no bands received here " << QTime::currentTime().toString("HH:mm:ss") << QTime::currentTime().toString("HH:mm:ss");
         return;
     }
 
@@ -492,26 +492,26 @@ void DXCCStatusWidget::setBands(const QString &_callingFunc, QStringList const &
     testBand.clear();
 
     bandNames.clear();
-    //qDebug() << "DXCCStatusWidget::setBands - 03 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 03 " << QTime::currentTime().toString("HH:mm:ss");
     validBands.clear();
     validBands = dataProxy->getBandNames();
-    //qDebug() << "DXCCStatusWidget::setBands - 04 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 04 " << QTime::currentTime().toString("HH:mm:ss");
     dxccView->clearSelection();
     dxccView->clear();
 
     for (int i = 0; i<qs.length(); i++)
     {
-        //qDebug() << "DXCCStatusWidget::setBands-4.1: " << qs.at(i) <<" - " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::setBands-4.1: " << qs.at(i) <<" - " << QTime::currentTime().toString("HH:mm:ss");
         testBand = qs.at(i);
 
         if (validBands.contains(qs.at(i)))
         {
             bandNames.append(testBand);
-            //qDebug() << "DXCCStatusWidget::setBands-4.2: Added: " << bandNames.last()  << " - " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::setBands-4.2: Added: " << bandNames.last()  << " - " << QTime::currentTime().toString("HH:mm:ss");
         }
         else
         {
-            //qDebug() << "DXCCStatusWidget::setBands -4.3 Not valid band: " << testBand << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::setBands -4.3 Not valid band: " << testBand << QTime::currentTime().toString("HH:mm:ss");
         }
     }
     dxccView->setColumnCount(0);
@@ -519,43 +519,43 @@ void DXCCStatusWidget::setBands(const QString &_callingFunc, QStringList const &
 
     while(dxccView->columnCount()>0)
     {
-        //qDebug() << "DXCCStatusWidget::setBands: Still pending: " << QString::number(dxccView->columnCount()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::setBands: Still pending: " << QString::number(dxccView->columnCount()) << QTime::currentTime().toString("HH:mm:ss");
         dxccView->removeColumn(0);
     }
     numberOfColumns = dxccView->columnCount();
-    //qDebug() << "DXCCStatusWidget::setBands: -6 All removed: " << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands: -6 All removed: " << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss");
     numberOfColumns = 2 + bandNames.length(); //Prefix, Entity Name
-    //qDebug() << "DXCCStatusWidget::setBands - 7.1 - columnCount: " << QString::number(dxccView->columnCount()) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::setBands - 7.1 - numberOfColumns: " << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 7.1 - columnCount: " << QString::number(dxccView->columnCount()) << QTime::currentTime().toString("HH:mm:ss");
+    //qDebug() << "DXCCStatusWidget::setBands - 7.1 - numberOfColumns: " << QString::number(numberOfColumns) << QTime::currentTime().toString("HH:mm:ss");
     dxccView->setColumnCount(numberOfColumns);
-   //qDebug() << "DXCCStatusWidget::setBands - 7.2 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+   //qDebug() << "DXCCStatusWidget::setBands - 7.2 " << QTime::currentTime().toString("HH:mm:ss");
     dxccView->setRowCount(0);
-    //qDebug() << "DXCCStatusWidget::setBands - 7.3 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 7.3 " << QTime::currentTime().toString("HH:mm:ss");
 
     QStringList headerqs;
-      //qDebug() << "DXCCStatusWidget::setBands - 7.4 " << QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::setBands - 7.4 " << QTime::currentTime()).toString("HH:mm:ss");
     headerqs.clear();
-    //qDebug() << "DXCCStatusWidget::setBands - 7.5 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 7.5 " << QTime::currentTime().toString("HH:mm:ss");
     headerqs << tr("Prefix") << tr("Entity") << bandNames;
-    //qDebug() << "DXCCStatusWidget::setBands - 8 " << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 8 " << QTime::currentTime().toString("HH:mm:ss");
     dxccView->setHorizontalHeaderLabels(headerqs);
 
-    //qDebug() << "DXCCStatusWidget::setBands - 9 PRE-END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands - 9 PRE-END" << QTime::currentTime().toString("HH:mm:ss");
 
     if (_creating)
     {
-        //qDebug() << "DXCCStatusWidget::setBands: 9.1 !_creating so updating!" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::setBands: 9.1 !_creating so updating!" << QTime::currentTime().toString("HH:mm:ss");
         update();
     }
 
-    //qDebug() << "DXCCStatusWidget::setBands: END" << QTime::currentTime().toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::setBands: END" << QTime::currentTime().toString("HH:mm:ss");
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
 }
 
 void DXCCStatusWidget::setDefaultBands()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-      //qDebug() << "DXCCStatusWidget::setDefaultBands" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::setDefaultBands";
     /*
      Default bands:
      160M    80M  40M  30M  20M  17M  15M  12M  10M  6M   4M   2M   70CM
@@ -567,7 +567,7 @@ void DXCCStatusWidget::setDefaultBands()
     bandNames << "160M" << "80M" << "40M" << "30M" << "20M" << "17M" << "15M" << "12M" << "10M";
 
     setBands(Q_FUNC_INFO, bandNames, false);
-    //qDebug << "DXCCStatusWidget::setDefaultBands - END" << QT_ENDL;
+    //qDebug << "DXCCStatusWidget::setDefaultBands - END";
     emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
@@ -575,11 +575,11 @@ void DXCCStatusWidget::slotRefreshButtonClicked()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
 
-      //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked";
     //TODO: Define a way to show the status of the selected log or all the logs in the DB
     if (dxccView->rowCount()<1)
     {
-          //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked - rowcount <1" << QT_ENDL;
+          //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked - rowcount <1";
         return;
     }
     QStringList _bands = bandNames;
@@ -594,7 +594,7 @@ void DXCCStatusWidget::slotRefreshButtonClicked()
 void DXCCStatusWidget::refresh()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-      //qDebug() << "DXCCStatusWidget::refresh" << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::refresh";
     //update();
     slotRefreshButtonClicked();
     emit debugLog (Q_FUNC_INFO, "END", Debug);
@@ -603,7 +603,7 @@ void DXCCStatusWidget::refresh()
  void DXCCStatusWidget::setCurrentLog(const int _logN)
  {
      emit debugLog (Q_FUNC_INFO, "Start", Debug);
-       //qDebug() << "DXCCStatusWidget::setCurrentLog: " << QString::number(_logN) << QT_ENDL;
+       //qDebug() << "DXCCStatusWidget::setCurrentLog: " << QString::number(_logN);
      if (dataProxy->doesThisLogExist(_logN))
      {
          logNumber = _logN;
@@ -617,9 +617,9 @@ void DXCCStatusWidget::refresh()
 
  void DXCCStatusWidget::slotItemEntered(QTableWidgetItem  * item )
  {
-    //qDebug << "DXCCStatusWidget::slotItemEntered: " << ((item->data(0)).toString()).simplified() << QT_ENDL;
-    //qDebug << "DXCCStatusWidget::slotItemEntered: " << item->text() << QT_ENDL;
-    //qDebug << "DXCCStatusWidget::slotItemEntered: " << QT_ENDL;
+    //qDebug << "DXCCStatusWidget::slotItemEntered: " << ((item->data(0)).toString()).simplified();
+    //qDebug << "DXCCStatusWidget::slotItemEntered: " << item->text();
+    //qDebug << "DXCCStatusWidget::slotItemEntered: ";
      emit debugLog (Q_FUNC_INFO, "Start", Debug);
     if (dxccView->rowCount()<1)
     {
@@ -639,8 +639,8 @@ void DXCCStatusWidget::refresh()
       //  row = dxccView->row(item);
         int column = dxccView->column(item);
 
-           //qDebug() << "DXCCStatusWidget::slotItemEntered: row: " << QString::number(row) << QT_ENDL;
-           //qDebug() << "DXCCStatusWidget::slotItemEntered: hrow: " <<  dxccView->verticalHeaderItem(row)->text() << QT_ENDL;
+           //qDebug() << "DXCCStatusWidget::slotItemEntered: row: " << QString::number(row);
+           //qDebug() << "DXCCStatusWidget::slotItemEntered: hrow: " <<  dxccView->verticalHeaderItem(row)->text();
       //  row = (dxccView->item(row,0)->text()).toInt();
 
         int entiID = dataProxy->getEntityIdFromMainPrefix(dxccView->item(dxccView->row(item),0)->text());
@@ -648,7 +648,7 @@ void DXCCStatusWidget::refresh()
         { // Some prefix are shown with a * in the begining that is removed to show the real prefix
             entiID = dataProxy->getEntityIdFromMainPrefix("*" + dxccView->item(dxccView->row(item),0)->text());
         }
-          //qDebug() << "DXCCStatusWidget::slotItemEntered: entiID: " << QString::number(entiID) << QT_ENDL;
+          //qDebug() << "DXCCStatusWidget::slotItemEntered: entiID: " << QString::number(entiID);
 
         if ((column == 0) || (column == 1))
         {
@@ -670,9 +670,9 @@ void DXCCStatusWidget::refresh()
             else
             {
                 QString band = dxccView->horizontalHeaderItem(column)->text();
-                   //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << band << QT_ENDL;
+                   //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << band;
                 int bandi = dataProxy->getIdFromBandName(band);
-                   //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << QString::number(bandi) << QT_ENDL;
+                   //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << QString::number(bandi);
                 if (item->text() == "C")
                 {
                     tip = awards->getQSOofAward(entiID, bandi, logNumber, true);
@@ -682,7 +682,7 @@ void DXCCStatusWidget::refresh()
                     tip = awards->getQSOofAward(entiID, bandi, logNumber, false);
                 }
 
-                   //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << QT_ENDL;
+                   //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip;
                 if (tip.length()>3)
                 {
                     tip = "QSO: " + tip;
@@ -701,18 +701,18 @@ void DXCCStatusWidget::refresh()
         }
 
         item->setToolTip(tip);
-           //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << QT_ENDL;
+           //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip;
     }
-      //qDebug() << "DXCCStatusWidget::slotItemEntered: END " << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::slotItemEntered: END ";
     emit debugLog (Q_FUNC_INFO, "END", Debug);
  }
 
 void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << ((item->data(0)).toString()).simplified() << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << item->text() << QT_ENDL;
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked - start" << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << ((item->data(0)).toString()).simplified();
+    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << item->text();
+    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked - start";
     if (dxccView->rowCount()<1)
     {
         return;
@@ -730,12 +730,12 @@ void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
 
     QTableWidgetItem * it = new QTableWidgetItem(0);
 
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - Columns: " << QString::number(columns)  << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - Columns: " << QString::number(columns) ;
 
     if (item)
     {
         row = dxccView->row(item);
-        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - row: "  << QString::number(row) << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - row: "  << QString::number(row);
 
         _entiNumb= dataProxy->getEntityIdFromMainPrefix(dxccView->item(dxccView->row(item),0)->text());
         if (_entiNumb<0)
@@ -743,22 +743,22 @@ void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
             _entiNumb= dataProxy->getEntityIdFromMainPrefix("*" + dxccView->item(dxccView->row(item),0)->text());
         }
        //_entiNumb = ((dxccView->item(row,0))->text()).toInt();
-          //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - EntityNumber: " << QString::number(_entiNumb) << QT_ENDL;
+          //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - EntityNumber: " << QString::number(_entiNumb);
 
        for (int i = 2; i < columns; ++i)
        {
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column: "  << QString::number(i) << QT_ENDL;
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << (dxccView->horizontalHeaderItem(i))->text() << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column: "  << QString::number(i);
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << (dxccView->horizontalHeaderItem(i))->text();
             //entityName = (dxccView->item(row,i))->text() ;
-              //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - item: "  << QT_ENDL;
+              //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - item: " ;
 
             it->setText(dxccView->item(row,i)->text());
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column-txt: "  << it->text() << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column-txt: "  << it->text();
 
             QString band = dxccView->horizontalHeaderItem(i)->text();
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << band << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << band;
             int bandi = dataProxy->getIdFromBandName(band);
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << QString::number(bandi) << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << QString::number(bandi);
             int qsoId = -1;
           if (item->text() == "C")
           {
@@ -769,28 +769,28 @@ void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
             qsoId = awards->getQSOIdofAward(_entiNumb, bandi, logNumber, false);
           }
 
-          //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: QSOid: " << QString::number(qsoId) << QT_ENDL;
+          //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: QSOid: " << QString::number(qsoId);
           if (qsoId>0)
           {
               qsos.append(qsoId);
           }
 
         }
-        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of for"  << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of for" ;
         if (qsos.length()>0)
         {
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - qsos.length = " << QString::number(qsos.length())  << QT_ENDL;
+            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - qsos.length = " << QString::number(qsos.length()) ;
             emit showQsos(qsos);
         }
-        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of column == 1"  << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of column == 1" ;
     }
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: END " << QT_ENDL;
+    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: END ";
 }
 
 void DXCCStatusWidget::setMyLocator(const QString &_loc)
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-      //qDebug() << "DXCCStatusWidget::setMyLocator: " << _loc << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::setMyLocator: " << _loc;
     QString l = _loc;
     if ( locator->isValidLocator(l.toUpper()) )
     {
@@ -801,7 +801,7 @@ void DXCCStatusWidget::setMyLocator(const QString &_loc)
 /*
 void DXCCStatusWidget::slotRightButton(const QPoint& pos)
 {
-       //qDebug() << "DXCCStatusWidget::slotRighButton"  << QT_ENDL;
+       //qDebug() << "DXCCStatusWidget::slotRighButton" ;
     int row = (dxccView->indexAt(pos)).row();
 
     showDXCCWikipediaAct = new QAction(tr("&Wikipedia"), this);
@@ -815,20 +815,20 @@ void DXCCStatusWidget::slotRightButton(const QPoint& pos)
 
 void DXCCStatusWidget::slotWikipedia()
 {
-       //qDebug() << "DXCCStatusWidget::slotWikipedia: " << (showDXCCWikipediaAct->data()).toString() << QT_ENDL;
+       //qDebug() << "DXCCStatusWidget::slotWikipedia: " << (showDXCCWikipediaAct->data()).toString();
     //TODO: To be added to the DXCCStatusWidget and create an action that emist the QSO id
     //int QSOid = ((logModel->index((showDXCCWikipediaAct->data()).toInt(), 0)).data(0)).toInt();
 
-      //qDebug() << "DXCCStatusWidget::slotQsoDeleteFromLog (id): " << QString::number(QSOid) << QT_ENDL;
+      //qDebug() << "DXCCStatusWidget::slotQsoDeleteFromLog (id): " << QString::number(QSOid);
 
 }
 
 void DXCCStatusWidget::righButtonFromLogMenu(const int trow)
 {
-        //qDebug() << "DXCCStatusWidget::slotshowRighButtonFromLogMenu:  " << QString::number(trow) << QT_ENDL;
+        //qDebug() << "DXCCStatusWidget::slotshowRighButtonFromLogMenu:  " << QString::number(trow);
 
     //int _qsoID = ((logModel->index(trow, 0)).data(0)).toInt();
-       //qDebug() << "DXCCStatusWidget::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID) << QT_ENDL;
+       //qDebug() << "DXCCStatusWidget::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID);
 
     QMenu menu(this);
 
