@@ -29,14 +29,14 @@ email                : jaime@robles.es
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
           : QWidget(parent)
 {
-       //qDebug() << "DXClusterWidget::DXClusterWidget" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::DXClusterWidget";
     dataProxy = dp;
     constrid = 1;
     awards = new Awards(dataProxy, Q_FUNC_INFO);
     util = new Utilities(Q_FUNC_INFO);
     saveSpotsFile = new QFile();
     //initClass();
-       //qDebug() << "DXClusterWidget::DXClusterWidget - END" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::DXClusterWidget - END";
 }
 */
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
@@ -44,7 +44,7 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
 //DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
 //          : QWidget(parent)
 {
-      //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << QT_ENDL;
+      //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect);
 
 
     saveSpotsFile = new QFile();
@@ -59,6 +59,7 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
     tcpSocket = new QTcpSocket(this);
 
     dxClusterListWidget = new QListWidget();
+
     inputCommand = new QLineEdit;
     sendButton = new QPushButton;
     clearButton = new QPushButton;
@@ -82,6 +83,7 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
 
     setLayout(layout);
 
+    dxClusterListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(sendButton , SIGNAL(clicked()), this, SLOT(slotClusterSendToServer()) );
     connect(inputCommand, SIGNAL(textChanged(QString)), this, SLOT(slotClusterInputTextChanged()) );
 
@@ -89,11 +91,9 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
     connect(dxClusterListWidget, SIGNAL(itemDoubleClicked ( QListWidgetItem *)), this, SLOT(slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * )) );
     connect(dxClusterListWidget, SIGNAL(itemEntered ( QListWidgetItem *)), this, SLOT(slotClusterDXClusterWidgetItemEntered( QListWidgetItem * )) );
     connect(dxClusterListWidget, SIGNAL(itemSelectionChanged()), this, SLOT(slotClusterDXClusterWidgetItemSelected() ) );
-
-
+    connect(dxClusterListWidget, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRighButton( const QPoint& ) ) );
      //TESTADDSPOT();
-       //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << QT_ENDL;
-
+       //qDebug() << "DXClusterWidget::DXClusterWidget2 - END" ;
 }
 
 DXClusterWidget::~DXClusterWidget()
@@ -105,9 +105,17 @@ DXClusterWidget::~DXClusterWidget()
     delete(saveSpotsFile);
 }
 
+void DXClusterWidget::createActions()
+{
+    checkQRZCOMFromLogAct = new QAction(tr("Check in QRZ.com"), this);
+    //checkQRZCOMFromLogAct->setShortcut(Qt::CTRL + Qt::Key_Q);
+    checkQRZCOMFromLogAct->setStatusTip(tr("Check this callsign in QRZ.com"));
+    connect(checkQRZCOMFromLogAct, SIGNAL(triggered()), this, SLOT( slotCheckQRZCom() ));
+
+}
+
 void DXClusterWidget::init()
 {
-
     dxSpotColor.setNamedColor("slategrey");
     dxClusterConnected = false;
     dxClusterAlreadyConnected = false;
@@ -129,6 +137,9 @@ void DXClusterWidget::init()
     saveSpotsFile->setFileName(util->getSaveSpotsLogFile());
 
     dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Click on connect to connect to the DX-Cluster"), awards->getDefaultColor());
+    Q_UNUSED(item);
+    createActions ();
+    //TODO: Check how to add an item in a different way
 }
 
 void DXClusterWidget::setMyQRZ(const QString &_qrz)
@@ -142,7 +153,7 @@ void DXClusterWidget::setMyQRZ(const QString &_qrz)
 
 void DXClusterWidget::addData()
 {
-       //qDebug() << "DXClusterWidget::addData " << QT_ENDL;
+       //qDebug() << "DXClusterWidget::addData ";
 
     /*
                 QTreeWidgetItem *item = new QTreeWidgetItem(searchResultsTreeWidget);
@@ -158,14 +169,14 @@ void DXClusterWidget::addData()
 */
 
     dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Click on connect to connect to the DX-Cluster"), awards->getDefaultColor());
-
+    Q_UNUSED(item);
 
 
 }
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item )
 {
-      //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << QT_ENDL;
+      //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text();
 
     QStringList ql;
     ql.clear();
@@ -173,31 +184,31 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetIt
     if (item)
     {
         ql = readItem(item);
-           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << QT_ENDL;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length()) ;
         if (ql.length()==2)
         {
             ql << "double";
-               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << QT_ENDL;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED" ;
             emit dxspotclicked(ql);
         }
         else
         {
-               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << QT_ENDL;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1" ;
         }
     }
     else
     {
-           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << QT_ENDL;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)" ;
     }
 
 }
 
 void DXClusterWidget::connectToDXCluster()
 {
-       //qDebug() << "DXClusterWidget::connectToDXCluster" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::connectToDXCluster";
     if (dxClusterConnected)
     {
-           //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << QT_ENDL;
+           //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!";
         return; // If we are connected we don't want to start another connection
     }
 
@@ -220,7 +231,7 @@ void DXClusterWidget::connectToDXCluster()
 
 void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socketError)
 {
-       //qDebug() << "DXClusterWidget:displayError:" << QT_ENDL;
+       //qDebug() << "DXClusterWidget:displayError:";
      switch (socketError) {
      case QAbstractSocket::RemoteHostClosedError:
          break;
@@ -258,23 +269,23 @@ bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int cons
 
     if (!showconfirmed)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << QT_ENDL;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")";
         if (status)
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << QT_ENDL;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band);
             return false;
         }
     }
 
     if (!showhf)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << QT_ENDL;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?";
         if (dataProxy->isHF(_band))
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << QT_ENDL;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?";
             if ( (showwarc) && dataProxy->isWARC(_band) )
             {
-                  //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << QT_ENDL;
+                  //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!";
                 return true;
             }
 
@@ -283,13 +294,13 @@ bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int cons
         }
         else
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << QT_ENDL;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF";
         }
     }
 
     if (!showwarc)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << QT_ENDL;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?";
         if (dataProxy->isWARC(_band))
         {
               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
@@ -297,13 +308,13 @@ bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int cons
         }
         else
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << QT_ENDL;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC";
         }
     }
 
     if (!showvhf)
     {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << QT_ENDL;
+           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?";
         if (dataProxy->isVHF(_band))
         {
                //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
@@ -311,7 +322,7 @@ bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int cons
         }
         else
         {
-               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << QT_ENDL;
+               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF ";
         }
     }
        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
@@ -333,7 +344,7 @@ void DXClusterWidget::setCurrentLog(const int _log)
 
 void DXClusterWidget::slotClusterDataArrived()
 {
-      //qDebug() << "DXClusterWidget::slotClusterDataArrived" << QT_ENDL;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived";
     QStringList qs;
     QString dxClusterString;
     QString dxCall;
@@ -357,11 +368,11 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         // It is a "DX de SP0TTER FREC DXCALL"
         //0 = DX, 1 = de, 2 = spotter, 3 = Freq, 4 = dxcall, 5 = comment
-          //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << QT_ENDL;
+          //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens;
 
         if ((tokens[0] == "DX") && (tokens[1] == "de"))
         {
-              //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << QT_ENDL;
+              //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE";
             //isADXSpot = true;
             QString spotter = tokens[2];
             spotter.truncate(spotter.size() - 1);
@@ -378,7 +389,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << QT_ENDL;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity);
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if  (showDxMarathon)
             {
@@ -389,20 +400,20 @@ void DXClusterWidget::slotClusterDataArrived()
             }
 
 
-              //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << QT_ENDL;
+              //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall;
 
         }
         else if ((tokens[0] == "To") && (tokens[1] == "ALL"))
         {
-              //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << QT_ENDL;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL";
             dxSpotColor = awards->getDefaultColor();
         }
         //else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
         else if ( (dxClusterString.length()>=5) && (util->isValidCall(tokens[1])) && (tokens[0]!="login:"))
         { // Freq / DXCall / Date // time
            //_qs << QRZ << Freq in MHz << lognumber;
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << QT_ENDL;
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << QT_ENDL;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5";
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1];
             //isADXSpot = true;
             dxCall = tokens[1];
             dxFrequency = tokens[0];
@@ -411,7 +422,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
             dxEntity = world->getQRZARRLId(dxCall);
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << QT_ENDL;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity);
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if (showDxMarathon)
@@ -424,7 +435,7 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         else
         {
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << QT_ENDL;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT";
             dxSpotColor = awards->getDefaultColor();
         }
 
@@ -433,12 +444,12 @@ void DXClusterWidget::slotClusterDataArrived()
         //qs << dxCall << spotBand << "0";
 
         //dxSpotColor = awards->getQRZDXStatusColor(qs);
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << QT_ENDL;
+           //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name();
         //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, dxClusterString, dxSpotColor);
         //TODO: Change the "-1" by the mode
         if (!checkIfNeedsToBePrinted(QString::number(dxEntity), spotBand.toInt(), -1))
         {
-              //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << QT_ENDL;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall;
             return;
         }
 
@@ -486,15 +497,15 @@ void DXClusterWidget::slotClusterDataArrived()
         //dxClusterListWidget->insertItem(0,item);
     }
 
-       //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << QT_ENDL;
+       //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString;
 
-      //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << QT_ENDL;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString;
 
 }
 
 void DXClusterWidget::slotClusterSocketConnected()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnected";
 
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
@@ -539,7 +550,7 @@ void DXClusterWidget::slotClusterSocketConnected()
 
 void DXClusterWidget::slotClusterSocketConnectionClosed()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed";
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
     item->setText(tr("Connection closed by the server"));
@@ -555,7 +566,7 @@ void DXClusterWidget::slotClusterSocketConnectionClosed()
 
 void DXClusterWidget::slotClusterSendToServer()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterSendToServer()";
     if (!dxClusterConnected)
     {
 
@@ -565,14 +576,14 @@ void DXClusterWidget::slotClusterSendToServer()
     if (( inputCommand ->text().length() < 1 ) && ( sendButton->text() == tr("Disconnect") ) )
     {
 
-        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Disconnecting" << QT_ENDL;
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Disconnecting";
         QTextStream os(tcpSocket);
         os << "bye\n";
         return;
     }
     else if ( inputCommand ->text().length() < 1 )
     {
-        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Empty" << QT_ENDL;
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Empty";
         return;
     }
 
@@ -585,14 +596,14 @@ void DXClusterWidget::slotClusterSendToServer()
 
 void DXClusterWidget::slotClusterClearLineInput()
 {
-       //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterClearLineInput";
 
     inputCommand->clear();
 }
 
 void DXClusterWidget::slotClusterInputTextChanged()
 {
-       //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterInputTextChanged";
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -608,14 +619,14 @@ void DXClusterWidget::slotClusterInputTextChanged()
 
 void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
 {
-       //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << QT_ENDL;
+       //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default;
     // Just to pass the colors to the awards class
     awards->setColors(_newOne,  _needed, _worked,  _confirmed, _default);
 }
 
 void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy )
 {
-       //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << QT_ENDL;
+       //qDebug() << "DXClusterWidget::setDXClusterSpotConfig ";
 
     showhf = _showhf;
     showvhf = _showvhf;
@@ -629,7 +640,7 @@ void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 {
-       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected ";
     QListWidgetItem * item = dxClusterListWidget->currentItem();
 
     QStringList ql;
@@ -645,7 +656,7 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item )
 {
-       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << QT_ENDL;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered";
 /*
     This code comes from slotClusterDXClusterWidgetItemDoubleClicked
 */
@@ -673,7 +684,8 @@ bool DXClusterWidget::isConnected()
 
 QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 {
-      //qDebug() << "DXClusterWidget::readItem" << QT_ENDL;
+    //qDebug() << "DXClusterWidget::readItem";
+    // Returns: fields << dxCallsign << dxFreq;
 
     QStringList fields;
     QString dxClusterString;
@@ -694,7 +706,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 
             if ( world->getQRZARRLId(fields.at(4))> 0 )
             {
-                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << QT_ENDL;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4))) ;
                 dxCallsign = (fields.at(4)).toUpper();
                 (fields.at(3)).toFloat(&FirstFrecOK);
                 if (FirstFrecOK)
@@ -716,7 +728,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
             else
             { // The callsign is not from a valid country
               // TODO: if it is from a new entity/prefix it would not work.
-                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << QT_ENDL;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid" ;
                 dxCallsign.clear();
                 dxFreq.clear();
                 fields.clear();
@@ -751,7 +763,12 @@ void DXClusterWidget::setDXClusterServer(const QString &clusterToConnect, const
 {
     server = clusterToConnect;
     port = quint16(portToConnect);
-       //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << QT_ENDL;
+    if ((server.length()< 3) || (port <= 0))
+    {
+        server = "dxfun.com";
+        port = 8000;
+    }
+
 }
 
 void DXClusterWidget::setDXMarathon (const bool _enable)
@@ -787,36 +804,94 @@ bool DXClusterWidget::openFile()
     }
 }
 
+void DXClusterWidget::slotRighButton(const QPoint& pos)
+{
+    //qDebug() << Q_FUNC_INFO;
+    Q_UNUSED(pos);
+    //int row = (dxClusterListWidget->indexAt(pos)).row();
+    //qDebug() << Q_FUNC_INFO << " row: " << QString::number(row);
+
+    QListWidgetItem * item = dxClusterListWidget->currentItem();
+
+    QStringList ql;
+    ql.clear();
+
+    ql = readItem(item); //qstringlist << dxCallsign << dxFreq;
+    if (ql.length()==2)
+    {
+        rightButtonFromLogMenu(ql);
+
+    }
+}
+void DXClusterWidget::rightButtonFromLogMenu(const QStringList _ql)
+{
+    // This function creates the context menu
+
+    checkQRZCOMFromLogAct->setData (_ql.at(0));
+    QMenu menu(this);
+    menu.addAction(checkQRZCOMFromLogAct);
+    menu.exec(QCursor::pos());
+}
+
+
+
+void DXClusterWidget::slotCheckQRZCom()
+{
+    QString _c = checkQRZCOMFromLogAct->data ().toString ();
+    util->openQrzcom (_c);
+}
+
+/*
+void DXClusterWidget::rightButtonFromLogMenu(const int trow)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(trow);
+    int _qsoID = ((logModel->index(trow, 0)).data(0)).toInt();
+}
+*/
 void DXClusterWidget::saveSpot(const QString &_spot)
 {
-      //qDebug() << "DXClusterWidget::saveSpot: " << _spot  << QT_ENDL;
+      //qDebug() << "DXClusterWidget::saveSpot: " << _spot ;
     if (!saveSpots)
     {
-          //qDebug() << "DXClusterWidget::saveSpot: Not saving" << QT_ENDL;
+          //qDebug() << "DXClusterWidget::saveSpot: Not saving";
         return;
     }
     else
     {
         if (openFile())
         {
-              //qDebug() << "DXClusterWidget::saveSpot: File Open" << QT_ENDL;
+              //qDebug() << "DXClusterWidget::saveSpot: File Open";
             QTextStream out(saveSpotsFile);
 
-            out << util->getDateTimeSQLiteStringFromDateTime(QDateTime::currentDateTime()) << " - " << _spot  << QT_ENDL;
+            out << util->getDateTimeSQLiteStringFromDateTime(QDateTime::currentDateTime()) << " - " << _spot ;
             saveSpotsFile->close();
         }
         else {
             {
-                  //qDebug() << "DXClusterWidget::saveSpot: File NOT Open" << QT_ENDL;
+                  //qDebug() << "DXClusterWidget::saveSpot: File NOT Open";
             }
         }
     }
 }
 
+void DXClusterWidget::loadSettings()
+{
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    QString aux = settings.value("DXClusterServerToUse").toString ();
+
+    if (aux.contains(':'))
+    {
+        setDXClusterServer((aux.split(':', QT_SKIP)).at(0), ((aux.split(':', QT_SKIP)).at(1)).toInt());
+    }
+
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
+
 /*
 void DXClusterWidget::TESTADDSPOT()
 {
-       //qDebug() << "DXClusterWidget::TESTADDSPOT "   << QT_ENDL;
+       //qDebug() << "DXClusterWidget::TESTADDSPOT "  ;
     ; // Just a test spot
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(dxSpotColor));
@@ -834,7 +909,7 @@ void DXClusterWidget::TESTADDSPOT()
 ** It may be moved to a self .h & .cpp archives                           **
 ****************************************************************************/
 dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot, const QColor& color ) : QListWidgetItem( parent ){
-       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << QT_ENDL;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor";
     spotColor = color;
     setText(spot);
     // Experimenting with fonts for the cluster
@@ -845,6 +920,6 @@ dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot,
 
 dxClusterSpotItem::~dxClusterSpotItem()
 {
-       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << QT_ENDL;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor";
 }
 
