@@ -35,7 +35,7 @@
 
 eLogClubLog::eLogClubLog()
 {
-     //qDebug()<< "eLogClubLog::eLogClubLog"  << QT_ENDL;
+    //qDebug()<< "eLogClubLog::eLogClubLog" ;
 
     //email = QString();
     //pass = QString();
@@ -47,23 +47,23 @@ eLogClubLog::eLogClubLog()
     //stationCallsign = QString();
     uploadingFile = false;
     util = new Utilities(Q_FUNC_INFO);
-     //qDebug()<< "eLogClubLog::eLogClubLog - END"  << QT_ENDL;
+    //qDebug()<< "eLogClubLog::eLogClubLog - END" ;
 }
 
 eLogClubLog::~eLogClubLog()
 {
     delete(util);
     delete(manager);
-         //qDebug()<< "eLogClubLog::~eLogClubLog"  << QT_ENDL;
+          //qDebug()<< "eLogClubLog::~eLogClubLog" ;
 }
 
 
  void eLogClubLog::slotQsoUploadFinished(QNetworkReply *data)
 {
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished"  << QT_ENDL;
+      //qDebug()<< "eLogClubLog::slotQsoUploadFinished" ;
 
     result = data->error();
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
+    //qDebug()<< Q_FUNC_INFO << " - Result = " << QString::number(result);
 
     const QByteArray sdata = data->readAll();
 
@@ -80,8 +80,8 @@ eLogClubLog::~eLogClubLog()
     {
 
         text = "ClubLog: " + prepareToTranslate(sdata);
-         //qDebug()<< sdata;
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - NO ERROR" << QT_ENDL;
+          //qDebug()<< sdata;
+          //qDebug()<< Q_FUNC_INFO << " - NO ERROR";
         if (uploadingFile)
         {
             uploadingFile = false;
@@ -94,30 +94,30 @@ eLogClubLog::~eLogClubLog()
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Host Not found! = " << QString::number(result)  << QT_ENDL;
+          //qDebug()<< Q_FUNC_INFO << " - Result = Host Not found! = " << QString::number(result) ;
         text = "ClubLog: " + tr("Host not found!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
     else if (result == QNetworkReply::TimeoutError)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Time out error! = " << QString::number(result)  << QT_ENDL;
+          //qDebug()<< Q_FUNC_INFO << " - Result = Time out error! = " << QString::number(result) ;
         text = "ClubLog: " + tr("Timeout error!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
-    /*
     else if (result == 201)
     {
         text = "ClubLog: " + tr("It seems to be a CREDENTIALS ERROR; check your email and password.");
 
-        int i = QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
+        QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
                                        tr("It seems that your ClubLog credentials are not correct.") + "\n" +
                                           tr("Please check your credentials in the setup. ClubLog uploads will be disabled."),
                                        QMessageBox::Ok);
         emit disableClubLogAction(true);
     }
+    /*
     else if (result == 202)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Password Error! = " << QString::number(result)  << QT_ENDL;
+          //qDebug()<< Q_FUNC_INFO << " - Result = Password Error! = " << QString::number(result) ;
         text = "ClubLog: " + tr("It seems to be a PASSWORD ERROR; check your password.");
 
         int i = QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
@@ -140,7 +140,7 @@ eLogClubLog::~eLogClubLog()
     }
     else
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = UNDEFINED = " << QString::number(result)  << QT_ENDL;
+          //qDebug()<< Q_FUNC_INFO << " - Result = UNDEFINED = " << QString::number(result) ;
         text = "ClubLog: " + tr("Undefined error number (#%1)... ").arg(result);
         QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
                                        tr("We have received an undefined error from Clublog (%1)").arg(result) + "\n" +
@@ -150,8 +150,8 @@ eLogClubLog::~eLogClubLog()
         //TODO: Mark the previous QSO as not sent to clublog
     }
 
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result Text = " << text << QT_ENDL;
+     //qDebug()<< Q_FUNC_INFO << " - Result = " << QString::number(result);
+     //qDebug()<< Q_FUNC_INFO << "  - Result Text = " << text;
     //emit done();
     //emit signalFileUploaded(result, qsos);
     emit showMessage(text);
@@ -160,10 +160,10 @@ eLogClubLog::~eLogClubLog()
 
 void eLogClubLog::slotFileUploadFinished(QNetworkReply *data)
 {
-        //qDebug()<< "eLogClubLog::slotFileUploadFinished"  << QT_ENDL;
+         //qDebug()<< "eLogClubLog::slotFileUploadFinished" ;
 
     result = data->error();
-         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << QT_ENDL;
+          //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result);
 
     const QByteArray sdata = data->readAll();
 
@@ -174,40 +174,40 @@ void eLogClubLog::slotFileUploadFinished(QNetworkReply *data)
     {
 
         text = "ClubLog: " + prepareToTranslate(sdata);
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = NoError = " << QString::number(result)  << QT_ENDL;
-            //qDebug()<< sdata;
+             //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = NoError = " << QString::number(result) ;
+             //qDebug()<< sdata;
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Host Not found! = " << QString::number(result)  << QT_ENDL;
+             //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Host Not found! = " << QString::number(result) ;
         text = "ClubLog: " + tr("Host not found!");
     }
     else if (result == QNetworkReply::TimeoutError)
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Time out error! = " << QString::number(result)  << QT_ENDL;
+             //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Time out error! = " << QString::number(result) ;
         text = "ClubLog: " + tr("Timeout error!");
     }
     else
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = UNDEFINED = " << QString::number(result)  << QT_ENDL;
+             //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = UNDEFINED = " << QString::number(result) ;
         text = "ClubLog: " + tr("Undefined error...");
     }
 
-         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << QT_ENDL;
+          //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result);
     //emit done();
     emit  showMessage(text);
 }
 
 void eLogClubLog::downloadProgress(qint64 received, qint64 total) {
-        //qDebug()<< "eLogClubLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
+         //qDebug()<< "eLogClubLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total);
 
-        //qDebug()<< received << total;
+         //qDebug()<< received << total;
     emit actionShowProgres(received, total);
 }
 
 void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-        //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
+         //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError);
     result = networkError;
 
     /*if (result == QNetworkReply::NoError)
@@ -216,11 +216,11 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
     else
     if (result == QNetworkReply::HostNotFoundError)
     {
-             //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found" << QT_ENDL;
+              //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found";
     }
     else
     {
-             //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!" << QT_ENDL;
+              //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!";
     }
     */
     //actionError(result);
@@ -229,39 +229,39 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 
 int eLogClubLog::sendQSO(QStringList _qso)
 {
-     //qDebug() << "eLogClubLog::sendQSO: " << email << "/" << pass << "/" << api  << QT_ENDL;
-      //qDebug()<< "eLogClubLog::sendQSO:: length = " << QString::number(_qso.length()) << QT_ENDL;
+      //qDebug() << "eLogClubLog::sendQSO: " << email << "/" << pass << "/" << api ;
+       //qDebug()<< "eLogClubLog::sendQSO:: length = " << QString::number(_qso.length());
     // First Data in the QStringList is the QSO id, not to be sent to clublog but used in the signal actionReturnDownload(const int _i, const int _qsoId);
    for(int i = 0; i<_qso.length(); i++)
     {
-        //qDebug()<< "eLogClubLog::sendQSO = qso-at: "<< QString::number(i) << "- " << _qso.at(i) << QT_ENDL;
+         //qDebug()<< "eLogClubLog::sendQSO = qso-at: "<< QString::number(i) << "- " << _qso.at(i);
     }
     if (_qso.length()!=18)
     {
-         //qDebug() << "eLogClubLog::sendQSO:: length - END" << QT_ENDL;
+          //qDebug() << "eLogClubLog::sendQSO:: length - END";
         return -1;
     }
 
     currentQSO = (_qso.at(0)).toInt();
     _qso.removeFirst();
     //_qso.removeFirst();
-    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE (before checking): " << _qso.at(16) << QT_ENDL;
-    //qDebug()<< "eLogClubLog::sendQSO default StationCallsign): " << stationCallsign << QT_ENDL;
+     //qDebug()<< "eLogClubLog::sendQSO CALL TO USE (before checking): " << _qso.at(16);
+     //qDebug()<< "eLogClubLog::sendQSO default StationCallsign): " << stationCallsign;
 
     QString tempCall = _qso.at(16);
     if (tempCall.length()<1)
     {
         tempCall = stationCallsign;
     }
-    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE: " << tempCall << QT_ENDL;
+     //qDebug()<< "eLogClubLog::sendQSO CALL TO USE: " << tempCall;
     _qso.removeLast();
 
     QString qso = getClubLogAdif(_qso);
-     //qDebug()<< "eLogClubLog::sendQSO: " << qso << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendQSO: " << qso;
     QUrlQuery params;
     params.addQueryItem("adif",qso);
-    //qDebug() << "eLogClubLog::sendQSO: QSO: " << qso << QT_ENDL;
-     //qDebug() << "eLogClubLog::sendQSO: END" << QT_ENDL;
+     //qDebug() << "eLogClubLog::sendQSO: QSO: " << qso;
+      //qDebug() << "eLogClubLog::sendQSO: END";
     uploadingFile = false;
     return sendDataParams(tempCall, params, true);
     //return sendData(tempCall, qso);
@@ -270,7 +270,7 @@ int eLogClubLog::sendQSO(QStringList _qso)
 /*
 int eLogClubLog::deleteQSOid(const int _qsoId)
 {
-    //qDebug()<< "eLogClubLog::deleteQSOid: " << QString::number(_qsoId) << QT_ENDL;
+     //qDebug()<< "eLogClubLog::deleteQSOid: " << QString::number(_qsoId);
    // email, password, callsign, dxcall, datetime, bandid, api
     QString dxcall, datatime, bandid;
     QUrlQuery params;
@@ -281,19 +281,21 @@ int eLogClubLog::deleteQSOid(const int _qsoId)
 
 int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_params, bool _adding)
 {
-     //qDebug()<< "eLogClubLog::sendDataParams: Call: " << _clublogCall << QT_ENDL;
-     //qDebug()<< "eLogClubLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
-     //qDebug()<< "eLogClubLog::sendDataParams: email = " << email << QT_ENDL;
-     //qDebug()<< "eLogClubLog::sendDataParams: Pass = " << pass << QT_ENDL;
+      //qDebug()<< Q_FUNC_INFO << ":  Call: " << _clublogCall;
+      //qDebug()<< Q_FUNC_INFO << ": : Params: " << _params.query(QUrl::FullyEncoded).toUtf8();
+      //qDebug()<< Q_FUNC_INFO << ":  email = " << email;
+      //qDebug()<< Q_FUNC_INFO << ":  Pass = " << pass;
 
     QUrl serviceUrl;
     if (_adding)
     {
-     serviceUrl = QUrl("https://secure.clublog.org/realtime.php");
+     //serviceUrl = QUrl("https://secure.clublog.org/realtime.php");
+        serviceUrl = QUrl("https://clublog.org/realtime.php");
     }
     else
     {
-     serviceUrl = QUrl("https://secure.clublog.org/delete.php");
+        //serviceUrl = QUrl("https://secure.clublog.org/delete.php");
+      serviceUrl = QUrl("https://clublog.org/delete.php");
     }
 
     QByteArray postData;
@@ -305,14 +307,14 @@ int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_p
     if  (_clublogCall.length()>2)
     {
         params.addQueryItem("callsign",_clublogCall);
-          //qDebug()<< "eLogClubLog::sendDataParams - callsign 1: " << _clublogCall << QT_ENDL;
+           //qDebug()<< Q_FUNC_INFO << ":  - callsign 1: " << _clublogCall;
     }
     else
     {
         params.addQueryItem("callsign",stationCallsign);
     }
 
-     //qDebug()<< "eLogClubLog::sendDataParams - query before send/delete: " << params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
+      //qDebug()<< Q_FUNC_INFO << ":  - query before send/delete: " << params.query(QUrl::FullyEncoded).toUtf8();
     if (_adding)
     {
         params.addQueryItem("api",api);
@@ -338,16 +340,16 @@ int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_p
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
 
-
+    //qDebug() << Q_FUNC_INFO << ": " << postData;
     manager->post(request, postData);
-     //qDebug()<< "eLogClubLog::sendDataParams - END" << QT_ENDL;
+    //qDebug()<< Q_FUNC_INFO << ":  - END";
     return -1;
 }
 
 /*
 int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
 {
-     //qDebug()<< "eLogClubLog::sendData: " << _q << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendData: " << _q;
 
     QUrl serviceUrl = QUrl("https://secure.clublog.org/realtime.php");
     QByteArray postData;
@@ -360,7 +362,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
     if  (_clublogCall.length()>2)
     {
         params.addQueryItem("callsign",_clublogCall);
-            //qDebug()<< "eLogClubLog::sendData - callsign 1: " << _clublogCall << QT_ENDL;
+             //qDebug()<< "eLogClubLog::sendData - callsign 1: " << _clublogCall;
     }
     else
     {
@@ -372,7 +374,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
     params.addQueryItem("adif",_q);
 
     postData = params.query(QUrl::FullyEncoded).toUtf8();
-      //qDebug()<< "eLogClubLog::sendData - query: " << postData << QT_ENDL;
+       //qDebug()<< "eLogClubLog::sendData - query: " << postData;
     //postData = params.encodedQuery();
 
     // Call the webservice
@@ -393,7 +395,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
 QString eLogClubLog::getClubLogAdif(const QStringList _q)
 
 {
-     //qDebug() << "eLogClubLog::getClubLogAdif: " << QString::number(_q.length()) << QT_ENDL;
+      //qDebug() << "eLogClubLog::getClubLogAdif: " << QString::number(_q.length());
     // _qso must include 16 ordered fields than can be empty or contain data. This function builds the ADIF QSO
 /* http://clublog.freshdesk.com/support/solutions/articles/53202-which-adif-fields-does-club-log-use-
 ClubLog only accepts the following ADIF fields:
@@ -424,48 +426,48 @@ NOTES
     }
     for (int i = 0; i< _q.length(); i++)
     {
-         //qDebug()<< QString("eLogClubLog::getClubLogAdif: (%1): %2").arg(i).arg(_q.at(i)) << QT_ENDL;
+          //qDebug()<< QString("eLogClubLog::getClubLogAdif: (%1): %2").arg(i).arg(_q.at(i));
     }
 
     QString qso, aux1;
     qso.clear();
     aux1 = _q.at(0);
-     //qDebug()<< "eLogClubLog::getClubLogAdif: Date: " << _q.at(0)  << QT_ENDL;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: Date: " << _q.at(0) ;
     if (QDate::fromString(aux1, "yyyyMMdd").isValid()){
 
         qso = "<QSO_DATE:" + QString::number(aux1.length()) + ">" +  aux1  +  " ";
     }
     else
     {
-         //qDebug() << "eLogClubLog::getClubLogAdif: END error " << QT_ENDL;
+          //qDebug() << "eLogClubLog::getClubLogAdif: END error ";
         return QString();
     }
 
     //qso = "<QSO_DATE:" + QString::number((_q.at(0)).length()) + ">" + _q.at(0) + " ";
     qso = qso + "<TIME_ON:" + QString::number((_q.at(1)).length()) + ">" + _q.at(1) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 10"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 10" ;
     if ((_q.at(2)).length()>0)
     {
         qso = qso + "<QSLRDATE:" + QString::number((_q.at(2)).length()) + ">" + _q.at(2) + " ";
     }
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 20"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 20" ;
     if ((_q.at(3)).length()>0)
     {
         qso = qso + "<QSLSDATE:" + QString::number((_q.at(3)).length()) + ">" + _q.at(3) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 30"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 30" ;
     qso = qso + "<CALL:" + QString::number((_q.at(4)).length()) + ">" + _q.at(4) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 40"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 40" ;
     if ((_q.at(5)).length()>0)
     {
         qso = qso + "<OPERATOR:" + QString::number((_q.at(5)).length()) + ">" + _q.at(5) + " ";
     }
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 50"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 50" ;
     qso = qso + "<MODE:" + QString::number((_q.at(6)).length()) + ">" + _q.at(6) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 60"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 60" ;
     qso = qso + "<BAND:" + QString::number((_q.at(7)).length()) + ">" + _q.at(7) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 70"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 70" ;
     if ((_q.at(8)).length()> 2)
     {
         qso = qso + "<BAND_RX:" + QString::number((_q.at(8)).length()) + ">" + _q.at(8) + " ";
@@ -477,54 +479,51 @@ NOTES
     }
 
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 90"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 90" ;
     qso = qso + "<QSL_RCVD:" + QString::number((_q.at(10)).length()) + ">" + _q.at(10) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 100" ;
     qso = qso + "<LOTW_QSL_RCVD:" + QString::number((_q.at(11)).length()) + ">" + _q.at(11) + " ";
-     //qDebug()<< "eLogClubLog::getClubLogAdif: 110"  << QT_ENDL;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 110" ;
     //qso = qso + "<QSL_SENT:" + QString::number((_q.at(12)).length()) + ">" + _q.at(12) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 120"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 120" ;
     if ((_q.at(13)).toInt()> 0)
     {
         qso = qso + "<DXCC:" + QString::number((_q.at(13)).length()) + ">" + _q.at(13) + " ";
     }
 
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 130'"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 130'" ;
     if ((_q.at(14)).toInt()> 0)
     {
         qso = qso + "<PROP_MODE:" + QString::number((_q.at(14)).length()) + ">" + _q.at(14) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 140"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 140" ;
     if ((_q.at(15)).length()>0)
     {
         qso = qso + "<CREDIT_GRANTED:" + QString::number((_q.at(15)).length()) + ">" + _q.at(15) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 150"  << QT_ENDL;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 150" ;
     qso = qso + "<EOR>";
-     //qDebug()<< "eLogClubLog:: - QSO: "  << qso << QT_ENDL;
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << QT_ENDL;
+      //qDebug()<< "eLogClubLog:: - QSO: "  << qso;
+       //qDebug()<< "eLogClubLog::getClubLogAdif: 100" ;
     return qso;
 }
 
-void eLogClubLog::setCredentials(const QString &_email, const QString &_pass, const QString &_defaultStationCallsign)
+void eLogClubLog::setDefaultCallsign(const QString &_defaultStationCallsign)
 {
-     //qDebug()<< "eLogClubLog::setCredentials: email: " << _email << " / Pass: " << _pass << " / StationCallsign: " << _defaultStationCallsign << QT_ENDL;
     stationCallsign = _defaultStationCallsign;
-    email = _email;
-    pass = _pass;
 }
 
 
 
 int eLogClubLog::deleteQSO(QStringList _qso)
 {
-     //qDebug()<< "eLogClubLog::deleteQSO: length = " << QString::number(_qso.length()) << QT_ENDL;
-     //qDebug()<< "eLogClubLog::deleteQSO: " << email << "/" << pass << "/" << api  << QT_ENDL;
-     //qDebug()<< "eLogClubLog::deleteQSO: email = " << email << QT_ENDL;
-     //qDebug()<< "eLogClubLog::deleteQSO: Pass = " << pass << QT_ENDL;
+      //qDebug()<< "eLogClubLog::deleteQSO: length = " << QString::number(_qso.length());
+      //qDebug()<< "eLogClubLog::deleteQSO: " << email << "/" << pass << "/" << api ;
+      //qDebug()<< "eLogClubLog::deleteQSO: email = " << email;
+      //qDebug()<< "eLogClubLog::deleteQSO: Pass = " << pass;
 
     // email, password, callsign, dxcall, datetime (sqlite format, not ADIF), bandid (only the number, not ADIF), api
     if (_qso.length()!=18)
@@ -533,7 +532,7 @@ int eLogClubLog::deleteQSO(QStringList _qso)
     }
     for (int i = 0; i<_qso.length(); i++)
     {
-         //qDebug()<< QString("eLogClubLog::deleteQSO: qso.at(%1) = %2").arg(i).arg(_qso.at(i)) << QT_ENDL;
+          //qDebug()<< QString("eLogClubLog::deleteQSO: qso.at(%1) = %2").arg(i).arg(_qso.at(i));
     }
 
     QString dxcall, sdateTime, bandid;
@@ -555,18 +554,18 @@ int eLogClubLog::deleteQSO(QStringList _qso)
     }
 
     sdateTime = dateTime.toString("yyyy-MM-dd HH:mm:ss");
-     //qDebug()<< QString("eLogClubLog::deleteQSO: DateTime = %1").arg(sdateTime) << QT_ENDL;
-      //qDebug()<< QString("eLogClubLog::deleteQSO: band-1: ") << _qso.at(8) << QT_ENDL;
+      //qDebug()<< QString("eLogClubLog::deleteQSO: DateTime = %1").arg(sdateTime);
+       //qDebug()<< QString("eLogClubLog::deleteQSO: band-1: ") << _qso.at(8);
     bandid = (_qso.at(8)).chopped(1);
-      //qDebug()<< QString("eLogClubLog::deleteQSO: band-2: ") << bandid << QT_ENDL;
+       //qDebug()<< QString("eLogClubLog::deleteQSO: band-2: ") << bandid;
     bool ok;
     bandid.toInt(&ok);
     if (!ok)
     { // This check is to capture potential QSOs in 222Mhz (AKA 1.25)
         bandid = bandid.chopped(1);
-         //qDebug()<< QString("eLogClubLog::deleteQSO: band-3: ") << bandid << QT_ENDL;
+          //qDebug()<< QString("eLogClubLog::deleteQSO: band-3: ") << bandid;
     }
-     //qDebug()<< QString("eLogClubLog::deleteQSO: bandid = %1").arg(bandid) << QT_ENDL;
+      //qDebug()<< QString("eLogClubLog::deleteQSO: bandid = %1").arg(bandid);
     if (bandid.toInt()<=0)
     {
         return -2;
@@ -586,7 +585,7 @@ int eLogClubLog::deleteQSO(QStringList _qso)
 
 QString eLogClubLog::prepareToTranslate(const QString &_m)
 {
-        //qDebug()<< "eLogClubLog:: = prepareToTranslate" << _m << QT_ENDL;
+         //qDebug()<< "eLogClubLog:: = prepareToTranslate" << _m;
     if (_m == "Callsign missing")
     {
         return tr("Callsign missing");
@@ -692,7 +691,7 @@ QString eLogClubLog::prepareToTranslate(const QString &_m)
 
 int eLogClubLog::modifyQSO (QStringList _oldQSO, QStringList _newQSO)
 {
-      //qDebug()<< QString("eLogClubLog::modifyQSO") << QT_ENDL;
+       //qDebug()<< QString("eLogClubLog::modifyQSO");
    int x = -1;
 
     x = deleteQSO(_oldQSO);
@@ -702,7 +701,7 @@ int eLogClubLog::modifyQSO (QStringList _oldQSO, QStringList _newQSO)
 
 void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overwrite)
 {
-      //qDebug()<< "eLogClubLog::sendLogFile: " << _file << QT_ENDL;
+    //qDebug()<< Q_FUNC_INFO << ": " << _file;
     qsos.clear();
     qsos.append(_qso);
     QUrl serviceUrl;
@@ -726,15 +725,15 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
     }
     else
     {
-          //qDebug()<< "eLogClubLog::sendLogFile: ERROR File not opened" << QT_ENDL;
+           //qDebug()<< Q_FUNC_INFO << ":  ERROR File not opened";
         return;
     }
     file->close();
     // The rest of the form goes as usual
-      //qDebug()<< "eLogClubLog::sendLogFile: email: " << email << QT_ENDL;
-      //qDebug()<< "eLogClubLog::sendLogFile: pass: " << pass << QT_ENDL;
-      //qDebug()<< "eLogClubLog::sendLogFile: stationcall: " << stationCallsign << QT_ENDL;
-      //qDebug()<< "eLogClubLog::sendLogFile: api: " << api << QT_ENDL;
+    //qDebug()<< Q_FUNC_INFO << ": email: " << email;
+    //qDebug()<< Q_FUNC_INFO << ": apPass: " << appPass;
+    //qDebug()<< Q_FUNC_INFO << ": stationcall: " << stationCallsign;
+    //qDebug()<< Q_FUNC_INFO << ": api: " << api;
 
     QHttpPart emailPart;
     emailPart.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant("form-data; name=\"email\""));
@@ -742,7 +741,7 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
 
     QHttpPart passPart;
     passPart.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant("form-data; name=\"password\""));
-    passPart.setBody(pass.toUtf8());
+    passPart.setBody(appPass.toUtf8());
 
     QHttpPart callPart;
     callPart.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant("form-data; name=\"callsign\""));
@@ -778,15 +777,23 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
     multiPart->append(clearPart);
     multiPart->append(apiPart);
 
-
     uploadingFile = true;
 
     QNetworkRequest request(serviceUrl);
     manager->post(request, multiPart);
-    //multiPart->setParent(reply);
+    //qDebug() << Q_FUNC_INFO << ": " << multiPart;
 
-      //qDebug()<< "eLogClubLog::sendLogFile - END" << QT_ENDL;
+    //qDebug()<< "eLogClubLog::sendLogFile - END";
+}
 
+void eLogClubLog::loadSettings()
+{
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("ClubLog");
+    email = settings.value ("ClubLogEmail").toString ();
+    pass = settings.value ("ClubLogPass").toString ();
+    appPass = settings.value ("ClubLogAppPass").toString ();
+    settings.endGroup ();
 }
 
 
