@@ -33,6 +33,7 @@
 
 eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, const QString &_klogVersion)
 {
+    Q_UNUSED(_parentFunction);
 #ifdef QT_DEBUG
   //qDebug() << Q_FUNC_INFO << ": " << _parentFunction;
 #endif
@@ -60,7 +61,7 @@ eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, con
     util->setSpecialCalls(dataProxy->getSpecialCallsigns());
    // serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
     //serviceUrl = QUrl("https://xmldata.qrz.com/xml/1.31/ ");
-   //qDebug()<< "eLogQrzLog::eLogQrzLog - END"  << QT_ENDL;
+   //qDebug()<< "eLogQrzLog::eLogQrzLog - END" ;
 }
 
 eLogQrzLog::~eLogQrzLog()
@@ -71,6 +72,8 @@ eLogQrzLog::~eLogQrzLog()
 
 void eLogQrzLog::showDebugLog(const QString &_func, const QString &_log)
 {
+    Q_UNUSED(_func);
+    Q_UNUSED(_log);
 #ifdef QT_DEBUG
   //qDebug() << _func << ": " << _log;
 #else
@@ -79,7 +82,7 @@ void eLogQrzLog::showDebugLog(const QString &_func, const QString &_log)
 
 void eLogQrzLog::setLogBookKey(const QString &_key)
 {
-    //qDebug()<< "eLogQrzLog::setLogBookKey: " << _key  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::setLogBookKey: " << _key ;
     showDebugLog (Q_FUNC_INFO, "Start: key: " + _key);
     if (_key.length()>0)
     {
@@ -118,25 +121,25 @@ void eLogQrzLog::parseNetworkError(QNetworkReply::NetworkError _error)
 
 void eLogQrzLog::slotManagerLogFinished(QNetworkReply *data)
 {
-    //qDebug()<< "eLogQrzLog::slotLogManagerFinished"  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::slotLogManagerFinished" ;
     showDebugLog (Q_FUNC_INFO, "Start");
     sendingQSO = false;
     result = data->error();
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result);
 
     const QByteArray sdata = data->readAll();
     //qDebug() << "eLogQrzLog::slotManagerLogFinished: Received: " << sdata;
 
     QString text = QString();
 
-    //qDebug() << "eLogQrzLog::slotManagerLogFinished - 00010" << QT_ENDL;
+    //qDebug() << "eLogQrzLog::slotManagerLogFinished - 00010";
     if (result == QNetworkReply::NoError)
     {
         QString dataReply(sdata);
         //parseAppAnswer(1, dataReply);
         parseAppAnswer(dataReply);
         showDebugLog (Q_FUNC_INFO, "No error");
-       //qDebug()<< "eLogQrzLog::slotManageLogFinished - NO ERROR" << QT_ENDL;
+       //qDebug()<< "eLogQrzLog::slotManageLogFinished - NO ERROR";
     }
     else {
         parseNetworkError(result);
@@ -150,8 +153,8 @@ void eLogQrzLog::slotManagerLogFinished(QNetworkReply *data)
         sendSignal(result, qsos);
     }
 
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << QT_ENDL;
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result Text = " << text << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result);
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result Text = " << text;
     showDebugLog (Q_FUNC_INFO, "Text: " + text);
     emit showMessage(text);
     showDebugLog (Q_FUNC_INFO, "END");
@@ -169,22 +172,22 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
         QXmlStreamReader::TokenType t = xml.readNext();
         if (t == QXmlStreamReader::StartDocument)
         {
-            //qDebug() << Q_FUNC_INFO << " - quick read version: " << xml.documentVersion().toString() << QT_ENDL;
-            //qDebug() << Q_FUNC_INFO << " - quick read encoding: " << xml.documentEncoding().toString() << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - quick read version: " << xml.documentVersion().toString();
+            //qDebug() << Q_FUNC_INFO << " - quick read encoding: " << xml.documentEncoding().toString();
         }
 
         if (t == QXmlStreamReader::StartElement)
         {
             QString name = xml.name().toString();
-            //qDebug() << Q_FUNC_INFO << " - quick read name: " << name << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - quick read name: " << name;
             if (name == "QRZDatabase" || name == "Session" || name == "Callsign")
             {
-                //qDebug() << Q_FUNC_INFO << " - No data: " << name << QT_ENDL;
+                //qDebug() << Q_FUNC_INFO << " - No data: " << name;
             }
             else if (name == "Key")
             {
                 tdata = xml.readElementText();
-                //qDebug() << Q_FUNC_INFO << " - API-Key: " << tdata << QT_ENDL;
+                //qDebug() << Q_FUNC_INFO << " - API-Key: " << tdata;
                 if (tdata.length()>0)
                 {
                     sessionkey = tdata;
@@ -197,7 +200,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
-                   //qDebug() << Q_FUNC_INFO << " - CALL: " << tdata << QT_ENDL;
+                   //qDebug() << Q_FUNC_INFO << " - CALL: " << tdata;
                 }
                 continue;
             }
@@ -206,7 +209,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
-                   //qDebug() << Q_FUNC_INFO << " - CALLSIGN: " << tdata << QT_ENDL;
+                   //qDebug() << Q_FUNC_INFO << " - CALLSIGN: " << tdata;
                 }
                 continue;
             }
@@ -215,7 +218,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
-                    //qDebug() << Q_FUNC_INFO << " - Name: " << tdata << QT_ENDL;
+                    //qDebug() << Q_FUNC_INFO << " - Name: " << tdata;
                 }
                 continue;
             }
@@ -224,14 +227,14 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
-                    //qDebug() << Q_FUNC_INFO << " - Country: " << tdata << QT_ENDL;
+                    //qDebug() << Q_FUNC_INFO << " - Country: " << tdata;
                 }
                 continue;
             }
             else if (name == "Error")
             {
                 tdata = xml.readElementText();
-                //qDebug() << Q_FUNC_INFO << " - Error: " << tdata << QT_ENDL;
+                //qDebug() << Q_FUNC_INFO << " - Error: " << tdata;
                 if (tdata == "Username/password incorrect ")
                 {
                     pass = QString();
@@ -242,7 +245,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
             else if (name == "Message")
              {
                  tdata = xml.readElementText();
-                 //qDebug() << Q_FUNC_INFO << " - Message: " << tdata << QT_ENDL;
+                 //qDebug() << Q_FUNC_INFO << " - Message: " << tdata;
                  emit dataFoundSignal("message", tdata);
                  continue;
              }
@@ -253,7 +256,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     emit dataFoundSignal("name", tdata);
-                    //qDebug() << Q_FUNC_INFO << " - FName: " << tdata << QT_ENDL;
+                    //qDebug() << Q_FUNC_INFO << " - FName: " << tdata;
                 }
                 continue;
             }
@@ -263,7 +266,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     //emit dataFoundSignal("grid", tdata);
-                   //qDebug() << Q_FUNC_INFO << " - addr1: " << tdata << QT_ENDL;
+                   //qDebug() << Q_FUNC_INFO << " - addr1: " << tdata;
                 }
                 continue;
             }
@@ -303,7 +306,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 //qDebug() << Q_FUNC_INFO << " - Remark: " << tdata ;
                 if (tdata.length()>0)
                 {
-                    //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << QT_ENDL;
+                    //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata;
                 }
                 continue;
             }
@@ -317,42 +320,42 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
             }
             else
             {
-                //qDebug() << Q_FUNC_INFO << " - ELSE quick read data: " << xml.readElementText() << QT_ENDL;
+                //qDebug() << Q_FUNC_INFO << " - ELSE quick read data: " << xml.readElementText();
             }
         }
     }
     if (xml.hasError())
     {
         showDebugLog (Q_FUNC_INFO, "Error: " + xml.errorString());
-        //qDebug() << Q_FUNC_INFO << " - ERROR: " << xml.errorString()  << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - ERROR: " << xml.errorString() ;
     }
     else if (xml.atEnd())
     {
-        //qDebug() << Q_FUNC_INFO << " - XML END"  << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - XML END" ;
     }
 /*
      QString tname, tdata;
      while(!xml.atEnd() && !xml.hasError())
      {
-         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00012" << QT_ENDL;
+         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00012";
          QXmlStreamReader::TokenType token = xml.readNext();
 
          if (token == QXmlStreamReader::StartDocument)
          {
-             //qDebug() << "eLogQrzLog::parseXMLAnswer - StartDocument" << QT_ENDL;
+             //qDebug() << "eLogQrzLog::parseXMLAnswer - StartDocument";
              continue;
          }
-         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00014" << QT_ENDL;
+         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00014";
          if (token == QXmlStreamReader::StartElement)
          {
              tname = xml.name().toString();
 
-            //qDebug() << "eLogQrzLog::parseXMLAnswer - tname = " << tname << QT_ENDL;
+            //qDebug() << "eLogQrzLog::parseXMLAnswer - tname = " << tname;
 
             if (tname == "Key")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: API-Key: " << tdata << QT_ENDL;
+                //qDebug() << "eLogQrzLog::parseXMLAnswer: API-Key: " << tdata;
                 if (tdata.length()>0)
                 {
                     sessionkey = tdata;
@@ -363,13 +366,13 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
             if (tname == "Error")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: Error: " << tdata << QT_ENDL;
+                //qDebug() << "eLogQrzLog::parseXMLAnswer: Error: " << tdata;
                 emit dataFoundSignal("error", tdata);
             }
             if (tname == "Message")
              {
                  tdata = xml.readElementText();
-                 //qDebug() << "eLogQrzLog::parseXMLAnswer: Message: " << tdata << QT_ENDL;
+                 //qDebug() << "eLogQrzLog::parseXMLAnswer: Message: " << tdata;
                  emit dataFoundSignal("message", tdata);
              }
             if (tname == "call")
@@ -377,7 +380,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: CALL: " << tdata << QT_ENDL;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: CALL: " << tdata;
                   }
                   continue;
               }
@@ -387,7 +390,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       emit dataFoundSignal("name", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: Name: " << tdata << QT_ENDL;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: Name: " << tdata;
                   }
                   continue;
               }
@@ -397,7 +400,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       //emit dataFoundSignal("grid", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr1: " << tdata << QT_ENDL;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr1: " << tdata;
                   }
                   continue;
               }
@@ -407,7 +410,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       emit dataFoundSignal("qth", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr2: " << tdata << QT_ENDL;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr2: " << tdata;
                   }
                   continue;
               }
@@ -431,38 +434,38 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
               }
             if (tname == "Remark")
               {
-                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: "  << QT_ENDL;
+                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " ;
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << QT_ENDL;
+                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata;
                   }
                   continue;
               }
             if (tname == "Session")
               {
-                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: "  << QT_ENDL;
+                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: " ;
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: " << tdata << QT_ENDL;
+                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: " << tdata;
                   }
                   continue;
               }
 
-              //qDebug() << "eLogQrzLog::parseXMLAnswer: Unknown: " << tname << QT_ENDL;
+              //qDebug() << "eLogQrzLog::parseXMLAnswer: Unknown: " << tname;
          }
      }
      if (xml.hasError())
      {
-           //qDebug() << "eLogQrzLog::parseXMLAnswer XML error: " << "XML error: " << xml.errorString() << QT_ENDL;
+           //qDebug() << "eLogQrzLog::parseXMLAnswer XML error: " << "XML error: " << xml.errorString();
      }
      else if (xml.atEnd())
      {
-           //qDebug() << "eLogQrzLog::parseXMLAnswer XML END: " << "Reached end, done" << QT_ENDL;
+           //qDebug() << "eLogQrzLog::parseXMLAnswer XML END: " << "Reached end, done";
      }
      */
-    //qDebug() << "eLogQrzLog::parseXMLAnswer: END of token while" << QT_ENDL;
+    //qDebug() << "eLogQrzLog::parseXMLAnswer: END of token while";
     //qDebug() << Q_FUNC_INFO << " - NO ERROR" ;
     showDebugLog (Q_FUNC_INFO, "END");
 }
@@ -472,14 +475,14 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
     //qDebug() << Q_FUNC_INFO;
     showDebugLog (Q_FUNC_INFO, "Start");
     result = data->error();
-    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result);
 
     const QByteArray sdata = data->readAll();
    //qDebug() << Q_FUNC_INFO << " - Received: " << sdata;
 
     QString text = QString();
 
-   //qDebug() << Q_FUNC_INFO << " - 00010" << QT_ENDL;
+   //qDebug() << Q_FUNC_INFO << " - 00010";
     if (result == QNetworkReply::NoError)
     {
         //QXmlStreamReader reader(sdata);
@@ -492,8 +495,8 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
         //parseNetworkError(result);
     }
 
-    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result) << QT_ENDL;
-    //qDebug() << Q_FUNC_INFO << " - Result Text = " << text << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result);
+    //qDebug() << Q_FUNC_INFO << " - Result Text = " << text;
 
     emit showMessage(text);
     showDebugLog (Q_FUNC_INFO, "Text: " + text);
@@ -502,7 +505,7 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
 }
 
 void eLogQrzLog::downloadProgress(qint64 received, qint64 total) {
-       //qDebug()<< "eLogQrzLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
+       //qDebug()<< "eLogQrzLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total);
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(received) +"/"+QString::number(total));
        //qDebug()<< received << total;
     emit actionShowProgres(received, total);
@@ -511,7 +514,7 @@ void eLogQrzLog::downloadProgress(qint64 received, qint64 total) {
 
 void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-       //qDebug()<< "eLogQrzLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
+       //qDebug()<< "eLogQrzLog::slotErrorManagement: " << QString::number(networkError);
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(networkError));
     result = networkError;
     /*
@@ -520,11 +523,11 @@ void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-            //qDebug()<< "eLogQrzLog::slotErrorManagement: Host not found" << QT_ENDL;
+            //qDebug()<< "eLogQrzLog::slotErrorManagement: Host not found";
     }
     else
     {
-            //qDebug()<< "eLogQrzLog::slotErrorManagement: ERROR!" << QT_ENDL;
+            //qDebug()<< "eLogQrzLog::slotErrorManagement: ERROR!";
     }
 
     */
@@ -576,10 +579,11 @@ void eLogQrzLog::fetchData()
 
 void eLogQrzLog::checkQRZ(const QString &_qrz)
 {
+    //qDebug() << Q_FUNC_INFO << ": " + _qrz;
     showDebugLog (Q_FUNC_INFO, "Start: " + _qrz);
     if (!util->isValidCall(_qrz))
     {
-        //qDebug()<< "eLogQrzLog::checkQRZ: CALL not valid"  << QT_ENDL;
+        //qDebug()<< "eLogQrzLog::checkQRZ: CALL not valid" ;
         showDebugLog (Q_FUNC_INFO, "CALL not valid");
         return;
     }
@@ -591,7 +595,7 @@ void eLogQrzLog::checkQRZ(const QString &_qrz)
         return;
     }
 
-    //qDebug() << Q_FUNC_INFO << " - Preparing the query"  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Preparing the query" ;
     QUrlQuery params;
     params.addQueryItem("s", sessionkey);
     params.addQueryItem("callsign", _qrz);
@@ -602,12 +606,12 @@ void eLogQrzLog::checkQRZ(const QString &_qrz)
 
 int eLogQrzLog::sendQSOs(QList<int> _qsos)
 {
-    //qDebug()<< "eLogQrzLog::sendQSOs: QSOs: " << QString::number(_qsos.length()) << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendQSOs: QSOs: " << QString::number(_qsos.length());
     showDebugLog (Q_FUNC_INFO, "Start");
     errorWhileSendingLog = false;
     if (logbookkey.length()<1)
     {
-        //qDebug()<< "eLogQrzLog::sendQSOs: No valid KEY (-2)" << QT_ENDL;
+        //qDebug()<< "eLogQrzLog::sendQSOs: No valid KEY (-2)";
         QMessageBox::warning(nullptr, tr("KLog - QRZ.com"),
                                        tr("Not valid KEY found") + "\n" +
                                           tr("Please configure your QRZ.com API key. You will find it in your QRZ.com Logbook settings webpage.\nYou need a QRZ.com subscription to use this feature."),
@@ -632,19 +636,19 @@ int eLogQrzLog::sendQSOs(QList<int> _qsos)
 
 int eLogQrzLog::sendQSO(const int _qsoID)
 {
-    //qDebug() << "eLogQrzLog::sendQSO: "  << QString::number(_qsoID) << QT_ENDL;
+    //qDebug() << "eLogQrzLog::sendQSO: "  << QString::number(_qsoID);
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(_qsoID));
     QString adifQSO = dataProxy->getADIFQSO(_qsoID);
 
-    //qDebug()<< "eLogQrzLog::sendQSO: (ADIF) :" << adifQSO << QT_ENDL;
-    //qDebug()<< "eLogQrzLog::sendQSO: (KEY) :" << logbookkey << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendQSO: (ADIF) :" << adifQSO;
+    //qDebug()<< "eLogQrzLog::sendQSO: (KEY) :" << logbookkey;
     QUrlQuery params;
 
     params.addQueryItem("KEY", logbookkey);
     params.addQueryItem("ACTION", "INSERT");
     params.addQueryItem("ADIF",adifQSO);
     params.addQueryItem("agent", util->getGlobalAgent(klogVersion));
-    //qDebug() << "eLogQrzLog::sendQSO: END" << QT_ENDL;
+    //qDebug() << "eLogQrzLog::sendQSO: END";
 
     QByteArray postData;
 
@@ -655,10 +659,10 @@ int eLogQrzLog::sendQSO(const int _qsoID)
     requestLog.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     showDebugLog (Q_FUNC_INFO, "postData: " + QString(postData));
 
-    //qDebug()<< "eLogQrzLog::sendQSO: postData: " << postData << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendQSO: postData: " << postData;
     while (sendingQSO)
     {
-        //qDebug() << "eLogQrzLog::sendQSO: sending QSO... just wait!" << QT_ENDL;
+        //qDebug() << "eLogQrzLog::sendQSO: sending QSO... just wait!";
     }
     managerLog->post(requestLog, postData);
     showDebugLog (Q_FUNC_INFO, "END");
@@ -682,11 +686,11 @@ bool eLogQrzLog::hasLogBookKey()
 
 void eLogQrzLog::login()
 {
-    //qDebug()<< "eLogQrzLog::login"  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::login" ;
     showDebugLog (Q_FUNC_INFO, "Start");
     if (logged)
     {
-        //qDebug()<< "eLogQrzLog::login Already logged!"  << QT_ENDL;
+        //qDebug()<< "eLogQrzLog::login Already logged!" ;
         showDebugLog (Q_FUNC_INFO, "END-1");
         return;
     }
@@ -709,7 +713,7 @@ void eLogQrzLog::login()
 
     if ((user.length()<1) || (pass.length()<1))
     {
-        //qDebug()<< "eLogQrzLog::login error 2"  << QT_ENDL;
+        //qDebug()<< "eLogQrzLog::login error 2" ;
         //if (!savePassword)
         //{// We delete the password as soon as possible if the user is not willing to save it
         //    pass = QString();
@@ -728,14 +732,14 @@ void eLogQrzLog::login()
     //{// We delete the password as soon as possible if the user is not willing to save it
     //        pass = QString();
     //}
-    //qDebug()<< "eLogQrzLog::login - END"  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::login - END" ;
     showDebugLog (Q_FUNC_INFO, "END");
 
 }
 
 int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
 {
-    //qDebug()<< "eLogQrzLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8();
     showDebugLog (Q_FUNC_INFO, "Start");
 
     QByteArray postData;
@@ -751,25 +755,31 @@ int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
     QNetworkRequest request(serviceUrl);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
-    //qDebug()<< "eLogQrzLog::sendDataParams: postData: " << postData << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendDataParams: postData: " << postData;
     manager->post(request, postData);
-     //qDebug()<< "eLogQrzLog::sendDataParams - END" << QT_ENDL;
+     //qDebug()<< "eLogQrzLog::sendDataParams - END";
     showDebugLog (Q_FUNC_INFO, "END");
     return -1;
 }
 
-void eLogQrzLog::setCredentials(const QString &_user, const QString &_pass)
+void eLogQrzLog::setUser(const QString &_user)
 {
-    //qDebug()<< "eLogQrzLog::setCredentials: user: " << _user << " / Pass: " << _pass  << QT_ENDL;
-    showDebugLog (Q_FUNC_INFO, "Start: " + _user + "/" + _pass);
+    showDebugLog (Q_FUNC_INFO, "Start: " + _user );
     user = _user;
+    showDebugLog (Q_FUNC_INFO, "END");
+}
+
+void eLogQrzLog::setPassword(const QString &_pass)
+{
+
+    showDebugLog (Q_FUNC_INFO, "Start: " + _pass);
     pass = _pass;
     showDebugLog (Q_FUNC_INFO, "END");
 }
 
 QString eLogQrzLog::prepareToTranslate(const QString &_m)
 {
-       //qDebug()<< "eLogQrzLog:: = prepareToTranslate" << _m << QT_ENDL;
+       //qDebug()<< "eLogQrzLog:: = prepareToTranslate" << _m;
     showDebugLog (Q_FUNC_INFO, "Start: " + _m);
     if (_m == "Callsign missing")
     {
@@ -783,7 +793,7 @@ QString eLogQrzLog::prepareToTranslate(const QString &_m)
 
 void eLogQrzLog::parseAppAnswer (const QString &_m)
 {
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: " << _m  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: " << _m ;
     showDebugLog (Q_FUNC_INFO, "Start: " + _m);
     QStringList response;
     response.clear();
@@ -791,12 +801,12 @@ void eLogQrzLog::parseAppAnswer (const QString &_m)
 
     QString responseType = response.at(0).split('=').at(0);
     QString responseResult = response.at(0).split('=').at(1);
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseType: " << responseType  << QT_ENDL;
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseResult: " << responseResult << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseType: " << responseType ;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseResult: " << responseResult;
 
     if ((responseType == "STATUS") && (responseResult == "OK"))
     {
-        //qDebug()<< "eLogQrzLog::parseAppAnswer: OK"  << QT_ENDL;
+        //qDebug()<< "eLogQrzLog::parseAppAnswer: OK" ;
     }
     else if ((responseType == "STATUS") && (responseResult == "FAIL"))
     {
@@ -804,7 +814,7 @@ void eLogQrzLog::parseAppAnswer (const QString &_m)
         if (response.at(1).split('=').at(0) == "REASON")
         {
             QString reason = response.at(1).split('=').at(1);
-           //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << QT_ENDL;
+           //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason ;
         }
     }
     else if ((responseType == "STATUS") && (responseResult == "AUTH"))
@@ -813,7 +823,7 @@ void eLogQrzLog::parseAppAnswer (const QString &_m)
         if (response.at(1).split('=').at(0) == "REASON")
         {
             QString reason = response.at(1).split('=').at(1);
-            //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << QT_ENDL;
+            //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason ;
             //onlineMessage->showMessage(QNetworkReply::NoError, QRZ, Fail, Other, reason);
         }
     }
