@@ -1,5 +1,5 @@
-#ifndef QSO_H
-#define QSO_H
+#ifndef KLOG_QSO_H
+#define KLOG_QSO_H
 /***************************************************************************
                           qso.h  -  description
                              -------------------
@@ -27,13 +27,16 @@
  *****************************************************************************/
 
 #include <QString>
+#include <QSqlQuery>
 #include <QDate>
 #include <QTime>
-//#include <QSqlQuery>
-#include <QDebug>
+#include <QObject>
+//#include <QDebug>
 #include "utilities.h"
 #include "klogdefinitions.h"
-#include <functional>
+#include "database.h"
+#include "adif.h"
+//#include <functional>
 
 class QSO : public QObject
 {
@@ -236,8 +239,6 @@ public:
     QDate getHRDUpdateDate();
     bool setHRDLogStatus(const QString &_c);
     QString getHRDLogStatus();
-    bool setFreq(const double _f);
-    double getFreq();
     bool setK_Index(const int _i);
     int getK_Index();
     bool setDateOff(const QDate &_c);
@@ -304,8 +305,8 @@ public:
     int getMyCQZone();
     bool setMyDXCC(const int _i);
     int getMyDXCC();
-    bool setMyFists(const QString &_c);
-    QString getMyFists();
+    bool setMyFists(const int _c);
+    int getMyFists();
     bool setMyIOTA(const QString &_c);
     QString getMyIOTA();
     bool setMyIotaID(const int _i);
@@ -362,6 +363,7 @@ public:
     int getStx();
     bool setStxString(const QString &_c);
     QString getStxString();
+    //bool setSubmode(const QString &_c, bool requestMode = false);
     bool setSubmode(const QString &_c);
     QString getSubmode();
     bool setSwl(bool _k);
@@ -378,16 +380,29 @@ public:
     QString getWwffRef();
     bool setMyWwffRef(const QString &_c);
     QString getMyWwffRef();
+    bool toDB(int _qsoId = 0);
+    //bool add();
+    //bool modify(const int _qsoId);
+    bool isComplete();
+    QString getADIF();
 
-    //QSqlQuery add();
 
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
+    void getBandSignal (double fr);         // Request the band to be filed for a given frequency
+    void getModeSignal (QString submode);   // Request the mode to be filled for a given submode
+    void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
 private:
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
+    QString getAddQueryString();
+    QString getModifyQueryString();
+    QSqlQuery getPreparedQuery(const QString &_s);
+    int getBandIdFromBandName(bool _rxBand=false);   // if rxBand = true, it will chec the bandRX
+    int getModeIdFromModeName();
 
-    int qsoId, logId, dxcc, a_index, k_index, cqz, fists, fists_cc, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
+
+    int qsoId, logId, dxcc, a_index, k_index, cqz, fists, fists_cc, my_fists, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
     int ten_ten, sfi;
     double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, freq, distance;
 
@@ -399,19 +414,21 @@ private:
     QString comment, address, ant_path, arrl_sect, continent, rig, country, award_granted, award_submitted, county, contacted_op, contacted_owner, contest_id;
     QString credit_granted, credit_submitted,darc_dok, email, qso_complete, usaca_counties, ve_prov, web, wwff_ref;
     QString iota, ownerCall, latitude, longitude, ms_shower, notes, prefix, precedence, public_key, qslmsg, region, sig, sig_info, skcc, srx_string, stx_string, state, submode;
-    QString my_city, my_county, my_country, my_fists, my_iota, my_latitude, my_longitude, my_name, my_postal_code, my_sig, my_sig_info, my_state, my_street, my_usaca_counties, my_wwff_ref;
+    QString my_city, my_county, my_country, my_iota, my_latitude, my_longitude, my_name, my_postal_code, my_sig, my_sig_info, my_state, my_street, my_usaca_counties, my_wwff_ref;
 
     QTime qso_time_off;
     QDateTime qso_dateTime;
 
     QDate QSLRDate, QSLSDate, QSLLoTWRDate, QSLLoTWSDate, qso_date_off;
-    QDate eQSLRDate, eQSLSDate, clublogDate,clublogQSOUpdateDate, hrdlogUploadDate;;
+    QDate eQSLRDate, eQSLSDate, clublogDate,clublogQSOUpdateDate, hrdlogUploadDate;
     QDate QRZComDate;
 
     bool backup, lotwUpdating, realTime, manualMode, silent_key;
     bool keepComment, keepOther, keepMyData, keepSat, modifying, isValidDistance, forceInit, qso_random, swl;
+    bool haveBand, haveMode, haveDateTime, haveCall;
 
     Utilities *util;
+    Adif *adif;
     DebugLogLevel logLevel;
 
    // DataProxy_SQLite *dataProxy;
@@ -429,6 +446,7 @@ private:
     bool setDXCC(const QString &data);
     bool setFists(const QString &data);
     bool setFistsCC(const QString &data);
+    bool setMyFists(const QString &data);
     bool setIotaID(const QString &data);
     bool setItuZone(const QString &data);
     bool setK_Index(const QString &data);
@@ -471,8 +489,6 @@ private:
     bool setLoTWQSLRDate2(const QString& data);
     bool setLoTWQSLSDate1(const QString& data);
     bool setLoTWQSLSDate2(const QString& data);
-
-
 };
 
 #endif // QSO_H
