@@ -1,5 +1,5 @@
-#ifndef HAMLIBNETWORKCONFIGWIDGET_H
-#define HAMLIBNETWORKCONFIGWIDGET_H
+#ifndef KLOG_SETUPPAGES_HAMLIBNETWORKCONFIGWIDGET_H
+#define KLOG_SETUPPAGES_HAMLIBNETWORKCONFIGWIDGET_H
 
 #include <QtWidgets>
 #include "../klogdefinitions.h"
