@@ -1,5 +1,5 @@
-#ifndef HAMLIBSERIALCONFIGWIDGET_H
-#define HAMLIBSERIALCONFIGWIDGET_H
+#ifndef KLOG_SETUPPAGES_HAMLIBSERIALCONFIGWIDGET_H
+#define KLOG_SETUPPAGES_HAMLIBSERIALCONFIGWIDGET_H
 
 #include <QtWidgets>
 #include <QSerialPortInfo>
