@@ -31,7 +31,7 @@
 //      instead. It is easy to change but the code would not be so clear... Think about this. :-)
 
 SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
-       //qDebug() << "SetupPageMisc::SetupPageMisc" << QT_ENDL;
+       //qDebug() << "SetupPageMisc::SetupPageMisc";
 
     util = new Utilities(Q_FUNC_INFO);
     checkCallsCheckBox = new QCheckBox(tr("Check non-valid calls"), this);
@@ -46,7 +46,7 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station &Callsign used in the search box"), this);
     //keepMyDataCheckBox = new QCheckBox(tr("&Reset to My Data for all QSOs"), this);
     checkNewVersionCheckBox = new QCheckBox(tr("&Check for new versions automatically"), this);
-    provideCallCheckBox = new QCheckBox(tr("&Provide Info for statistics"), this);
+    //provideCallCheckBox = new QCheckBox(tr("&Provide Info for statistics"), this);
     useDxMarathonCheckBox = new QCheckBox(tr("Manage DX-Marathon"), this);
 
     //logSortCheckBox = new QCheckBox(tr("Sort log based in date && time"));
@@ -61,7 +61,6 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     fileNameButton = new QPushButton (tr("Browse"));
     dbPushButton = new QPushButton (tr("Browse"));
     moveDBPushButton = new QPushButton(tr("Move DB"));
-
     dbPathApplied = true;
 
     createUI();
@@ -75,12 +74,12 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     {
         moveDBPushButton->setEnabled(true);
     }
-       //qDebug() << "SetupPageMisc::SetupPageMisc - END" << QT_ENDL;
+       //qDebug() << "SetupPageMisc::SetupPageMisc - END";
 }
 
 SetupPageMisc::~SetupPageMisc(){
     delete(util);
-       //qDebug() << "SetupPageMisc::~SetupPageMisc" << QT_ENDL;
+       //qDebug() << "SetupPageMisc::~SetupPageMisc";
 }
 
 void SetupPageMisc::createUI()
@@ -92,11 +91,11 @@ void SetupPageMisc::createUI()
 
     //TODO: To be removed when the defaultDir is saved in the config file
     #ifdef Q_OS_WIN
-       //qDebug() << "WINDOWS DETECTED!"  << QT_ENDL;
+       //qDebug() << "WINDOWS DETECTED!" ;
     klogDir = util->getHomeDir();  // We create the \klog for the logs and data
     defaultFileName = klogDir+"/klog.adi";
     #else
-       //qDebug() << "NO WINDOWS DETECTED!"  << QT_ENDL;
+       //qDebug() << "NO WINDOWS DETECTED!" ;
     klogDir = util->getHomeDir();  // We create the ~/.klog for the logs and data
     defaultFileName = klogDir+"/klog.adi";
     #endif
@@ -134,7 +133,7 @@ void SetupPageMisc::createUI()
     showStationCallWhenSearchCheckBox->setToolTip(tr("The search box will also show the callsign on the air to do the QSO."));
     //keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
     checkNewVersionCheckBox->setToolTip(tr("Check if there is a new release of KLog available every time you start KLog."));
-    provideCallCheckBox->setToolTip(tr("If new version checking is selected, KLog will send the developer your callsign, KLog version and Operating system to help in improving KLog."));
+    //provideCallCheckBox->setToolTip(tr("If new version checking is selected, KLog will send the developer your callsign, KLog version and Operating system to help in improving KLog."));
     imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometers)."));
     realTimeCheckbox->setToolTip(tr("Select to use real time."));
     UTCCheckbox->setToolTip(tr("Select to use UTC time."));
@@ -196,7 +195,7 @@ void SetupPageMisc::createUI()
     mainLayout->addWidget(sendQSLWhenRecCheckBox,6, 0, 1, 1);
     mainLayout->addWidget(sendEQSLByDefaultSearchCheckBox, 6, 1, 1, 1);
     mainLayout->addWidget(checkNewVersionCheckBox, 7, 0, 1, 1);
-    mainLayout->addWidget(provideCallCheckBox, 7, 1, 1, 1);
+    //mainLayout->addWidget(provideCallCheckBox, 7, 1, 1, 1);
     //mainLayout->addWidget(logSortCheckBox, 8, 0, 1, 1);
     mainLayout->addWidget(showStationCallWhenSearchCheckBox, 8, 0, 1, 1);
     mainLayout->addWidget(deleteAlwaysAdiFileCheckBox, 8, 1, 1, 1);
@@ -227,7 +226,7 @@ void SetupPageMisc::createActions(){
 void SetupPageMisc::setDeleteAlwaysAdiFile(const bool &_t){
 
     deleteAlwaysAdiFileCheckBox->setChecked(_t);
-    //qDebug() << "SetupPageMisc::setDeleteAlwaysAdiFile - DELETEALWAYSADIFILE = " << _t << QT_ENDL;
+    //qDebug() << "SetupPageMisc::setDeleteAlwaysAdiFile - DELETEALWAYSADIFILE = " << _t;
 }
 
 QString SetupPageMisc::getDeleteAlwaysAdiFile(){
@@ -292,8 +291,15 @@ QString SetupPageMisc::getDefaultFileName()
 }
 void SetupPageMisc::setDefaultFileName(const QString &_t)
 {
-       //qDebug() << "SetupPageMisc::setDefaultFileName: " << _t << QT_ENDL;
-    defaultFileName = _t;
+       //qDebug() << "SetupPageMisc::setDefaultFileName: " << _t;
+    if (_t.length ()<1)
+    {
+        defaultFileName = util->getDebugLogFile ();
+    }
+    else
+    {
+        defaultFileName = _t;
+    }
     defaultFileNameLineEdit->setText(defaultFileName);
 }
 
@@ -333,7 +339,7 @@ void SetupPageMisc::setImperial(const QString &_t)
 
 void SetupPageMisc::slotUseDefaultButtonStateChanged(int state)
 {
-       //qDebug() << "SetupPageMisc::slotUseDefaultButtonStateChanged" << QT_ENDL;
+       //qDebug() << "SetupPageMisc::slotUseDefaultButtonStateChanged";
 
     if (state)
     {
@@ -397,12 +403,12 @@ void SetupPageMisc::slotcheckNewVersionCheckBoxClicked()
 {
     if (checkNewVersionCheckBox->isChecked())
     {
-        provideCallCheckBox->setEnabled(true);
+        //provideCallCheckBox->setEnabled(true);
     }
     else
     {
-        provideCallCheckBox->setEnabled(false);
-        provideCallCheckBox->setChecked(false);
+        //provideCallCheckBox->setEnabled(false);
+        //provideCallCheckBox->setChecked(false);
     }
 }
 
@@ -416,16 +422,6 @@ void SetupPageMisc::setCheckNewVersions(const QString &_t)
     checkNewVersionCheckBox->setChecked(util->trueOrFalse(_t));
 }
 
-bool SetupPageMisc::getReportInfo()
-{
-    return checkNewVersionCheckBox->isChecked();
-}
-
-void SetupPageMisc::setReportInfo(const QString &_t)
-{
-    provideCallCheckBox->setChecked(util->trueOrFalse(_t));
-}
-
 QString SetupPageMisc::getDefaultDBPath()
 {
     return dbDirCurrent;
@@ -434,9 +430,15 @@ QString SetupPageMisc::getDefaultDBPath()
 
 void SetupPageMisc::setUseDefaultDBPath(const QString &_t)
 {
-    dbDirCurrent = _t;
+    if (_t.isEmpty ())
+    {
+        dbDirCurrent = util->getHomeDir();
+    }
+    else
+    {
+        dbDirCurrent = _t;
+    }
     dbPathLineEdit->setText(dbDirCurrent);
-
 }
 
 
@@ -490,7 +492,7 @@ void SetupPageMisc::slotDBButtonClicked()
 
 void SetupPageMisc::slotDBLineEditChanged()
 {
-       //qDebug() << "SetupPageMisc::slotDBLineEditChanged: " << dbPathLineEdit->text() << QT_ENDL;
+       //qDebug() << "SetupPageMisc::slotDBLineEditChanged: " << dbPathLineEdit->text();
     QString aux;
     aux = dbPathLineEdit->text();
 
@@ -525,15 +527,13 @@ void SetupPageMisc::slotMoveDBButtonClicked()
     QMessageBox msgBox;
     msgBox.setWindowTitle(tr("KLog - Move DB"));
 
-       //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (source): " << source << QT_ENDL;
-       //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target): " << target << QT_ENDL;
+       //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (source): " << source;
+       //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target): " << target;
     if ( QFile::exists(dbDirNew) )
     {
-        //dbDirCurrent
-        //dbDir
         if (QFile::exists(target))
         {
-            //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target EXISTS): " << target << QT_ENDL;
+            //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target EXISTS): " << target;
         }
         if (QFile::copy(source, target))
         {
@@ -547,11 +547,9 @@ void SetupPageMisc::slotMoveDBButtonClicked()
                 msgBox.setDefaultButton(QMessageBox::Ok);
                 msgBox.exec();
                 dbPathApplied = true;
-
             }
             else
             {
-
                 msgBox.setIcon(QMessageBox::Warning);
                 msgBox.setText(tr("File copied"));
                 msgBox.setStandardButtons(QMessageBox::Ok);
@@ -569,28 +567,25 @@ void SetupPageMisc::slotMoveDBButtonClicked()
 
             if (QFile::exists(target))
             {
-                //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target EXISTS): " << target << QT_ENDL;
+                //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target EXISTS): " << target;
 
                 msgBox.setText(tr("File already exist."));
                 msgBox.setDetailedText(tr("The destination file already exist and KLog will not replace it. Please remove the file from the destination folder before moving the file with KLog to make sure KLog can copy the file."));
+                dbPathApplied = true;
             }
             else
             {
-
                 msgBox.setText(tr("File NOT copied"));
                 msgBox.setDetailedText(tr("The file was not copied due to an unknown problem."));
-
+                dbPathApplied = false;
             }
             msgBox.exec();
-            dbPathApplied = false;
+
             moveDBPushButton->setEnabled(true);
         }
-
-
     }
     else
     {
-
         msgBox.setIcon(QMessageBox::Warning);
         msgBox.setText(tr("The target directory does not exist. Please select an existing directory."));
         msgBox.setStandardButtons(QMessageBox::Ok);
@@ -626,3 +621,60 @@ void SetupPageMisc::setCheckCalls(const bool &_t)
     checkCallsCheckBox->setChecked (_t);
 }
 
+void SetupPageMisc::saveSettings()
+{
+    //qDebug() << Q_FUNC_INFO ;
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Misc");
+    settings.setValue ("RealTime", QVariant((realTimeCheckbox->isChecked())));
+    settings.setValue ("ShowSeconds", QVariant((showSecondsCheckBox->isChecked())));
+    settings.setValue ("UTCTime", QVariant((UTCCheckbox->isChecked())));
+    settings.setValue ("AlwaysADIF", QVariant((alwaysADIFCheckBox->isChecked())));
+    settings.setValue ("UseDefaultName", QVariant((useDefaultName->isChecked())));
+    settings.setValue ("DefaultADIFFile", defaultFileName);
+    settings.setValue ("DBPath", dbDirCurrent);
+    settings.setValue ("ImperialSystem", QVariant((imperialCheckBox->isChecked())));
+    settings.setValue ("SendQSLWhenRec", QVariant((sendQSLWhenRecCheckBox->isChecked())));
+    settings.setValue ("ShowCallsignInSearch", QVariant((showStationCallWhenSearchCheckBox->isChecked())));
+    settings.setValue ("CompleteWithPrevious", QVariant((completeWithPreviousCheckBox->isChecked())));
+    settings.setValue ("CheckNewVersions", QVariant((checkNewVersionCheckBox->isChecked())));
+    settings.setValue ("ManageDXMarathon", QVariant((useDxMarathonCheckBox->isChecked())));
+    settings.setValue ("DebugLog", debugLogLevelCombo->currentText ());
+    settings.setValue ("SendEQSLByDefault", QVariant((sendEQSLByDefaultSearchCheckBox->isChecked())));
+    settings.setValue ("DeleteAlwaysAdiFile", QVariant((deleteAlwaysAdiFileCheckBox->isChecked())));
+    settings.setValue ("CheckValidCalls", QVariant((checkCallsCheckBox->isChecked())));
+    settings.setValue ("DuplicatedQSOSlot", dupeTimeLineEdit->text());
+    //settings.setValue ("ProvideInfo", QVariant((provideCallCheckBox->isChecked())));
+
+    //stream << "PSTRotatorActive=" << interfacesWindowsPage->getSendToPSTRotator() << ";";
+    //stream << "PSTRotatorServer=" << interfacesWindowsPage->getPSTRotatorUDPServer() << ";";
+    //stream << "PSTRotatorPort=" << interfacesWindowsPage->getPSTRotatorUDPServerPort() << ";";
+    settings.endGroup ();
+}
+
+void SetupPageMisc::loadSettings()
+{
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Misc");
+    realTimeCheckbox->setChecked (settings.value("RealTime").toBool ());
+    showSecondsCheckBox->setChecked (settings.value("ShowSeconds").toBool ());
+    UTCCheckbox->setChecked (settings.value("UTCTime").toBool ());
+    alwaysADIFCheckBox->setChecked (settings.value("AlwaysADIF").toBool ());
+    useDefaultName->setChecked (settings.value("UseDefaultName").toBool ());
+    imperialCheckBox->setChecked (settings.value("ImperialSystem").toBool ());
+    sendQSLWhenRecCheckBox->setChecked (settings.value("SendQSLWhenRec").toBool ());
+    showStationCallWhenSearchCheckBox->setChecked (settings.value("ShowCallsignInSearch").toBool ());
+    completeWithPreviousCheckBox->setChecked (settings.value("CompleteWithPrevious").toBool ());
+    checkNewVersionCheckBox->setChecked (settings.value("CheckNewVersions").toBool ());
+    useDxMarathonCheckBox->setChecked (settings.value("ManageDXMarathon").toBool ());
+    sendEQSLByDefaultSearchCheckBox->setChecked (settings.value("SendEQSLByDefault").toBool ());
+    deleteAlwaysAdiFileCheckBox->setChecked (settings.value("DeleteAlwaysAdiFile").toBool ());
+    checkCallsCheckBox->setChecked (settings.value("CheckValidCalls").toBool ());
+    //provideCallCheckBox->setChecked (settings.value("ProvideInfo").toBool ());
+
+    setDefaultFileName(settings.value("DefaultADIFFile").toString ());
+    setUseDefaultDBPath(settings.value("DBPath").toString ());
+    setDebugLogLevel(settings.value("DebugLog").toString ());
+    dupeTimeLineEdit->setText (settings.value("DuplicatedQSOSlot").toString ());
+    settings.endGroup ();
+}
