@@ -1,5 +1,5 @@
-#ifndef UTILITIES_H
-#define UTILITIES_H
+#ifndef KLOG_UTILITIES_H
+#define KLOG_UTILITIES_H
 /***************************************************************************
                           utilities.h  -  description
                              -------------------
@@ -33,6 +33,7 @@
     This classs hould not need to query the DB neither the DataProxy Class
 
 */
+#include <iostream>
 #include <QObject>
 #include <QtGlobal>
 #include <QString>
@@ -114,6 +115,7 @@ public:
     bool isValidQSL_Rcvd(const QString &c);
     bool isValidQSL_Sent(const QString &c);
     bool isValidUpload_Status(const QString &c);
+    bool isValidFISTS(const QString &c);
 
     bool isValidTimeFromString(const QString &_s);
     bool isValidDateFromString(const QString &_s);
@@ -124,6 +126,7 @@ public:
     bool isValidContinent(const QString &_s);
     bool isValidPropMode(const QString &_s);
     QStringList getValidADIFFieldAndData(const QString &_b);
+    //QString getADIFField(const QString &_fieldName, const QString &_data);
 
     QString getMainCallFromComplexCall(const QString &_complexCall); // F from F/EA4K/p, EA4K from EA4K/p or EA4K from EA4K
     QString getAValidCall (const QString &_wrongCall);
@@ -169,12 +172,14 @@ public:
     QStringList getDebugLevels();
     void setLogLevel(DebugLogLevel _l);
     void openQrzcom(const QString _call);
+    void printCommandHelp();
     //QPalette getPalete(bool _ok);
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
 
 private:
     void init();
+    void InitializeHash();
     void setLogColumnNames(); // Creates the map of column Names (should be called from init() )
     bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
@@ -201,6 +206,8 @@ private:
     QStringList longPrefixes, specialCalls;
     QMap<QString, QString> columnNames;
     bool validateCalls;
+    QHash<QString, QString> ADIFHash; // Name, type
+
 };
 
 #endif // UTILITIES_H
